@@ -151,6 +151,7 @@ static Tcl_CmdProc RatDbaseCheck;
 static Tcl_CmdProc RatMangleNumberCmd;
 static Tcl_CmdProc RatEncodingCompatCmd;
 static Tcl_CmdProc RatFormatDateCmd;
+static char *getValidFilename();
 
 
 /*
@@ -177,8 +178,8 @@ main(int argc, char **argv)
     char **fargv, *dir;
     struct stat sbuf;
 
-    setlocale(LC_CTYPE, "");
-    setlocale(LC_COLLATE, "");
+    /* setlocale(LC_CTYPE, "");
+       setlocale(LC_COLLATE, ""); */
 
     fargv = (char**)malloc((argc+1)*sizeof(char*));
     fargv[fargc++] = argv[0];
@@ -1074,7 +1075,9 @@ RatHandleSender(ClientData clientData, int mask)
 	    time_t dnow;
 
 	    if (!strcmp(destArgv[4], "recipient")) {
-		name = argv[3];
+		if ( ( name = getValidFilename( argv[3] ) ) == NULL ) {
+		    name = "Unresolved";
+		}
 	    } else if (!strcmp(destArgv[4], "sender")) {
 		name = argv[4];
 	    } else if (!strcmp(destArgv[4], "date")) {
@@ -1103,7 +1106,7 @@ RatHandleSender(ClientData clientData, int mask)
  	    cPtr = newArgv[3]+strlen(newArgv[3]);
  	    *cPtr++ = '/';
  	    for (i=0; name[i] && name[i] != '@'; i++) {
- 		*cPtr++ = name[i];
+		*cPtr++ = name[i];
  	    }
  	    *cPtr = '\0';
  	    free(destArgv);
@@ -1233,6 +1236,86 @@ RatHandleSender(ClientData clientData, int mask)
     free(argv);
 }
 
+/*
+ *----------------------------------------------------------------------
+ *
+ * getValidFilename --
+ *
+ * Parses an address of the form "Real Name <realname@someplace.com>" to
+ * return either "Real Name" or "realname" (without quotes).  Any leading
+ * quote character in the given address is ignored.
+ *
+ * Results:
+ *      Either a valid filename, or NULL.
+ *
+ *
+ *----------------------------------------------------------------------
+ */
+
+static char*
+getValidFilename( char *address )
+{
+
+    char *filename;
+    int i;
+
+    char *buf = (char *) malloc( sizeof( address ) );
+    int bufpos = 0;
+    char *start = address;
+    int count = 0;
+
+    /* Ignore a leading " character */
+    if ( address[0] == '"' ) start++;
+
+    for ( i = start - address; i < strlen( address ); i++ )
+    {
+	char current = address[i];
+
+	/* If we encounter a < then we've found the end of the real name */
+	if ( current == '<' )
+	{
+	    /* Set the end point, accounting for the space between the name
+	       and the < character */
+	    count = address + i - start - 1;
+	    break;
+	}
+
+	/* If we encounter an @ sign, then we've found the end of the
+	   recipient's name */
+	if ( current == '@' )
+	{
+	    /* Set the end point */
+	    count = address + i - start;
+	    break;
+	}
+    }
+
+    if ( count == 0 )
+    {
+        filename = NULL;
+    }
+    else
+    {
+	/* Remove any unwanted characters */
+	for ( i = 0; i < count; i++ )
+	{
+	    if ( start[i] != '"' )
+	    {
+		buf[ bufpos++ ] = start[i];
+	    }
+	}
+
+	/* Copy the resulting filename into the return variable */
+	filename = malloc( bufpos + 1 );
+	strncpy( filename, buf, bufpos );
+	filename[ bufpos ] = '\0';
+    }
+
+    free( buf );
+
+    return filename;
+}
+
 /*
  *----------------------------------------------------------------------
  *
