@@ -211,9 +211,9 @@ RatFolderCmd(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
 	    && (length > 1)) {
 	int i, number, expunge, oldNumber, oldVisible, delta;
 
-	if (argc != 3 || TCL_OK != Tcl_GetBoolean(interp, argv[2], &expunge)) {
+	if (argc != 4 || TCL_OK != Tcl_GetBoolean(interp, argv[2], &expunge)) {
 	    Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
-		    " update expunge\"", (char *) NULL);
+		    " update expunge sort-method\"", (char *) NULL);
 	    return TCL_ERROR;
 	}
 	oldVisible = infoPtr->visible;
@@ -227,6 +227,9 @@ RatFolderCmd(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
 	    RatLog(interp, RAT_WARN, interp->result, 0);
 	    number = 0;
 	} else {
+	    char *sort_method = argv[3];
+
+	    RatStdFolderSetSortMethod(infoPtr, sort_method);
 	    delta = number - oldNumber;
 	    infoPtr->number = number;
 	    if (delta <0) {
@@ -264,6 +267,8 @@ RatFolderCmd(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
 	    return TCL_ERROR;
 	}
 	ckfree(infoPtr->name);
+	if (infoPtr->sortMethod != NULL) 
+	    ckfree(infoPtr->sortMethod);
 	for(i=0; i < infoPtr->number; i++) {
 	    if (NULL != infoPtr->msgCmdPtr[i]) {
 		(void)RatMessageDelete(interp, infoPtr->msgCmdPtr[i]);
@@ -597,7 +602,7 @@ RatFolderCmd(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
 static void
 RatFolderSort(Tcl_Interp *interp, RatFolderInfo *infoPtr)
 {
-    char *sortMethod=Tcl_GetVar2(interp,"option","folder_sort",TCL_GLOBAL_ONLY);
+    char *sortMethod;
     int i, j, k, snarf, numParm, seen, *tmpPtr,
 	*p=infoPtr->presentationOrder,
 	reverse=0, needDate=0, needSubject=0, needSender=0,
@@ -606,6 +611,8 @@ RatFolderSort(Tcl_Interp *interp, RatFolderInfo *infoPtr)
     SortData *dataPtr, *dPtr;
     char *s, **pArgv;
 
+    if ((sortMethod = infoPtr->sortMethod) == NULL)
+	sortMethod = Tcl_GetVar2(interp,"option","folder_sort",TCL_GLOBAL_ONLY);
     Tcl_GetBoolean(interp, Tcl_GetVar2(interp, "option", "dsn_snarf_reports",
 	    TCL_GLOBAL_ONLY), &snarf);
 
