@@ -235,6 +235,10 @@ RatSenderSend(Tcl_Interp *interp, char *prefix, Tcl_DString *usedVariablesPtr,
 	    }
 	}
 	if (!adrPtr) {
+	    if (useFrom && (tmp = Tcl_GetVar2(interp, handler, "from", TCL_GLOBAL_ONLY))
+		&& !RatIsEmpty(tmp)) {
+		rfc822_parse_adrlist(&env->sender, tmp, currentHost);
+	    }
 	    env->sender = mail_newaddr();
 	    env->sender->personal =
 		    currentPersonalName ? cpystr(currentPersonalName) : NULL;
