@@ -462,6 +462,43 @@ OpenStdFolder(Tcl_Interp *interp, char *name, char *prot, char *user,
 }
 
 
+/*
+ *----------------------------------------------------------------------
+ *
+ * RatStdFolderSetSortMethod --
+ *
+ *      Sets, clears, or resets the folder's sort method.
+ *
+ * Results:
+ *      Nothing.
+ *
+ * Side effects:
+ *    The folder's sort method is changed.
+ *
+ *
+ *----------------------------------------------------------------------
+ */
+
+void
+RatStdFolderSetSortMethod(RatFolderInfo *infoPtr, char *sort_method)
+{
+    /*
+     * Free any existing sortMethod, so we don't leak memory.
+     */
+    if (infoPtr->sortMethod != NULL)
+	ckfree(infoPtr->sortMethod);
+    
+    /*
+     * Allow both NULL and the empty string to mean, a null setting.
+     */
+    if (sort_method != NULL && *sort_method)
+	infoPtr->sortMethod = cpystr(sort_method);
+    else
+	infoPtr->sortMethod = NULL;
+}
+
+
+
 /*
  *----------------------------------------------------------------------
  *
@@ -489,6 +526,10 @@ RatStdFolderCreate(Tcl_Interp *interp, int argc, char *argv[])
     StdFolderInfo *stdPtr;
     MAILSTREAM *stream = NULL;
     int new;
+    char *filename;
+    char *sort_method = NULL;
+    char *user = NULL;
+    char *protocol = NULL;
 
     /*
      * Now it is time to initialize things
@@ -497,19 +538,22 @@ RatStdFolderCreate(Tcl_Interp *interp, int argc, char *argv[])
 	env_parameters(SET_LOCALHOST, currentHost);
 	initialize = 0;
     }
-    if (argc != 3 && argc != 5) {
+    if (argc != 4 && argc != 6) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
-		" ", argv[1], " name [user prot]\"", (char *) NULL);
+		" ", argv[1], " mailbox-filename sort-method [user prot]\"",
+		(char *) NULL);
 	return (RatFolderInfo *) NULL;
     }
 
     stdPtr = (StdFolderInfo *) ckalloc(sizeof(*stdPtr));
 
-    if (5 == argc) {
-	stream = OpenStdFolder(interp, argv[2], argv[4], argv[3], stdPtr);
-    } else {
-	stream = OpenStdFolder(interp, argv[2], NULL, NULL, stdPtr);
+    filename = argv[2];
+    sort_method = argv[3];
+    if (6 == argc) {
+	user = argv[4];
+	protocol = argv[5];
     }
+    stream = OpenStdFolder(interp, filename, protocol, user, stdPtr);
     if (!stream && !stdPtr->isNotYet) {
 	free(stdPtr);
 	return NULL;
@@ -520,6 +564,14 @@ RatStdFolderCreate(Tcl_Interp *interp, int argc, char *argv[])
     infoPtr->name = cpystr(argv[2]);
     infoPtr->type = "std";
     infoPtr->size = -1;
+
+    /*
+     * Make sure sortMethod is initialised properly.  (I don't know 
+     * if ckalloc() zeroes the memory it has allocated.)
+     */
+    infoPtr->sortMethod = NULL;
+
+    RatStdFolderSetSortMethod(infoPtr, sort_method);
     if (stdPtr->isNotYet) {
 	infoPtr->number = 0;
     } else {
@@ -604,12 +656,20 @@ static int
 Std_CloseProc(RatFolderInfoPtr infoPtr, Tcl_Interp *interp)
 {
     StdFolderInfo *stdPtr = (StdFolderInfo *) infoPtr->private;
+    int expunge;
 
     if (stdPtr->isNotYet) {
+	/* LK: Why doesn't this free stdPtr->origName etc.? */
 	ckfree(stdPtr);
+	infoPtr->private = NULL;
 	return TCL_OK;
     }
-    /*    mail_expunge(stdPtr->stream); */
+    Tcl_GetBoolean(interp,
+	   Tcl_GetVar2(interp, "option", "expunge_on_close", TCL_GLOBAL_ONLY),
+	   &expunge);
+    if (expunge) {
+	mail_expunge(stdPtr->stream);
+    }
     CloseStdFolder(interp, stdPtr->stream);
     if (0 == --stdPtr->referenceCount) {
 	Tcl_HashEntry *entryPtr;
@@ -622,6 +682,7 @@ Std_CloseProc(RatFolderInfoPtr infoPtr, Tcl_Interp *interp)
 	}
 	ckfree(stdPtr->origName);
 	ckfree(stdPtr);
+	infoPtr->private = NULL;
     }
     return TCL_OK;
 }
@@ -1472,6 +1533,7 @@ void mm_login (NETMBX *mbPtr, char *user, char *pwd, long trial)
     char **largv, buf[1024];
     MMPasswd *pwPtr;
     int largc, timeout;
+    Tcl_DString ds;
 
     /*
      * Check for cached entry
@@ -1499,13 +1561,18 @@ void mm_login (NETMBX *mbPtr, char *user, char *pwd, long trial)
 	    return;
 	}
     }
-    sprintf(buf, " %lx ", trial);
-    if (TCL_OK != Tcl_VarEval(stdInterp, "RatLogin ", mbPtr->host, buf,
-			      loginUser?loginUser:"{}", " ",
-			      mbPtr->service?mbPtr->service:"", NULL)
+    sprintf(buf, "%lx", trial);
+    Tcl_DStringInit(&ds);
+    Tcl_DStringAppendElement(&ds, "RatLogin");
+    Tcl_DStringAppendElement(&ds, mbPtr->host);
+    Tcl_DStringAppendElement(&ds, buf);
+    Tcl_DStringAppendElement(&ds, loginUser?loginUser:"");
+    Tcl_DStringAppendElement(&ds, mbPtr->service?mbPtr->service:"");
+    if (TCL_OK != Tcl_Eval(stdInterp, Tcl_DStringValue(&ds))
 	    || TCL_OK != Tcl_SplitList(stdInterp, stdInterp->result,
 		    &largc,&largv)
 	    || 2 != largc) {
+	Tcl_DStringFree(&ds);
 	return;
     }
     strcpy(user, largv[0]);
@@ -1516,6 +1583,7 @@ void mm_login (NETMBX *mbPtr, char *user, char *pwd, long trial)
 	passwdCandidate->password = cpystr(largv[1]);
 	passwdCandidate->user = loginUser;
     }
+    Tcl_DStringFree(&ds);
     ckfree(largv);
 }
 
