@@ -390,6 +390,7 @@ proc AliasDelete {handler} {
 	set aliasMod 1
 	RatAlias delete $alias
     }
+    AddressesPopulate $handler
 }
 
 # AddrbookImport --
@@ -1094,17 +1095,9 @@ proc ReadMailAliases {file book} {
     set fh [open $file r]
     while { -1 != [gets $fh line]} {
 	if [string match {alias *} $line] {
-	    regsub -all {[ 	][ 	]} $line { } line
-	    set a [split $line]
-	    set content ""
-	    foreach e [lrange $a 2 end] {
-		set content "$content [string trim $e]"
-	    }
-	    if [string length [string trim [lindex $a 1]]] {
-		RatAlias add $book \
-			     [string trim [lindex $a 1]] \
-			     [string trim [lindex $a 1]] \
-			     [string trim $content] {}
+ 	    if [regexp "^alias\[ \t\]+(\[a-zA-Z0-9_-\]+)\[ \t\]+(.+)$" $line \
+ 		    {} name content] {
+ 		RatAlias add $book $name $name $content {}
 		incr n
 	    }
 	}
