@@ -36,6 +36,9 @@ set composeHeaderList {to subject cc bcc keywords content_description
 # List of headers which contains addresses (OBS! must be lower case OBS!)
 set composeAdrHdrList {to cc bcc reply_to}
 
+# List of bounce header names we allow
+set bounceHeaderList {to cc bcc reply_to comments}
+
 # Compose --
 #
 # Initialize the composing of a new letter
@@ -47,12 +50,16 @@ proc Compose { fhandler } {
     global idCnt
 
     set handler composeM[incr idCnt]
+    upvar #0 $handler mh
+    set mh(whence) compose
     return [DoCompose $handler $fhandler 0 1]
 }
 
 proc DropCompose {filename} {
     global idCnt
     set handler composeM[incr idCnt]
+    upvar #0 $handler mh
+    set mh(whence) compose
     DropAttach $handler $filename
     return [DoCompose $handler dummy 0 1]
 }
@@ -75,11 +82,173 @@ proc ComposeReply {fhandler msg to quote} {
     }
     set handler [$msg reply $to]
     upvar #0 $handler mh
-    if $quote {unset mh(data)}
+    upvar #0 $fhandler fh
+    set mh(whence) reply
+    if $quote {
+	unset mh(data)
+    } elseif ![catch {$fh(text) index sel.first} top] {
+	set bot [$fh(text) index sel.last]
+	set data [string range $mh(data) 0 [string first "\n" $mh(data)]]
+	for {set i [expr int($top)]} {$i<$bot} {incr i} {
+	    if {$i == [expr int($top)]} {
+		set data "$data$option(reply_lead) [$fh(text) get sel.first $i.end] \n"
+	    } elseif {$i == [expr int($bot)]} {
+		set data "$data$option(reply_lead) [$fh(text) get $i.0 $bot] \n"
+	    } else {
+		set data "$data$option(reply_lead) [$fh(text) get $i.0 $i.end] \n"
+	    }
+	}
+	set mh(data) $data
+    }
     set mh(whence) reply
     return [DoCompose $handler $fhandler 1 1]
 }
 
+# ComposeBounce --
+#
+# Forward a message and keep the first part inline if it is a text part.
+#
+# Arguments:
+# fhandler  -   The handler for the parent folder window
+# msg -		Message to forward
+proc ComposeBounce {fhandler msg} {
+    global idCnt option t b activeCompose bounceHeaderList
+    set handler composeM[incr idCnt]
+    upvar #0 $handler mh
+
+    set mh(parent) $fhandler
+    set mh(closing) 0
+    set mh(save_to) ""
+    set mh(request_dsn) $option(dsn_request)
+    set mh(toplevel) $handler
+    set mh(composeBody) dummy
+    set mh(answer) 0
+    set mh(attachmentList) {}
+    set mh(pgp_sign) 0
+    set mh(pgp_encrypt) 0
+    set mh(whence) bounce
+    if ![string length $msg] {
+	return 0
+    }
+
+    foreach header [$msg headers full] {
+	set name [string tolower [lindex $header 0]]
+	switch $name {
+	    from        { set mh(from) [join [lindex $header 1]]}
+	    date        { set mh(date) [join [lindex $header 1]] }
+	    subject	{ set mh(subject) [join [lindex $header 1]] }
+	    reply-to    { set mh(reply_to) [join [lindex $header 1]] }
+	    message-id  { set mh(message_id) [join [lindex $header 1]] }
+	    in-reply-to { set mh(in_reply_to) [join [lindex $header 1]] }
+	}
+    }
+    # Initialize variables
+    foreach i $bounceHeaderList {
+	set mh(O_$i) 0
+    }
+    regsub -all -- - [string tolower $option(compose_headers)] _ vars
+    foreach i $vars {
+	set mh(O_$i) 1
+    }
+
+    set body [$msg body]
+    set type [string tolower [$body type]]
+
+    set bhandler composeM[incr idCnt]
+    upvar #0 $bhandler bh
+    set mh(body) $bhandler
+    set mh(font) [GetFont $option(charset) 0 {}]
+    set bh(type) [lindex $type 0]
+    set bh(subtype) [lindex $type 1]
+    set bh(encoding) [$body encoding]
+    set bh(parameter) [$body params]
+    set bh(pgp_sign) 0
+    set bh(pgp_encrypt) 0
+    set bh(id) [$body id]
+    set bh(description) [$body description]
+    set mh(data) [$body data 0]
+    set mh(to) ""
+
+    # Create identifier
+    set w .$handler
+    set mh(oldFocus) [focus]
+    set activeCompose $handler
+    set mh(w) $w
+
+    # Create toplevel
+    toplevel $w -class Postilion
+    wm title $w $t(bounce_to)?
+    wm transient $w .
+    wm group $w .
+    wm protocol $w WM_DELETE_WINDOW \
+	"ComposeBounceDone $handler abort"
+
+    # Header fields
+    set mh(headerFrame) $w.desc
+    frame $mh(headerFrame) -relief flat -bd 1
+    set first [ComposeBuildHeaderEntries $handler]
+
+    # The command buttons
+    frame $w.buttons
+
+    # The send button
+    button $w.buttons.send -relief raised \
+	-command "ComposeBounceDone $handler send" \
+	-takefocus 0 -anchor center
+    set b($w.buttons.send) send
+    lappend mh(edit_block) $w.buttons.send 
+		
+    # The send and save button
+    menubutton $w.buttons.sendsave -highlightthickness 0 \
+	-takefocus 0 -menu $w.buttons.sendsave.m -relief raised \
+	-underline 0 -anchor center
+    set b($w.buttons.sendsave) sendsave
+    menu $w.buttons.sendsave.m -tearoff 0 \
+	    -postcommand "RatSendSavePostMenu $w $w.buttons.sendsave.m $handler"
+    lappend mh(edit_block) $w.buttons.sendsave
+		
+    # The addresslist button
+    button $w.buttons.address -highlightthickness 0 \
+	-command "CreateAddressWin" \
+	-takefocus 0 -anchor center 
+    set b($w.buttons.address) aliases
+    lappend mh(edit_block) $w.buttons.address
+
+    if $option(image_buttons) {
+	$w.buttons.send configure -image sndbut -height 60 -width 60
+	$w.buttons.sendsave configure -image savbut -height 60 -width 60
+	$w.buttons.address configure -image addrbut -height 60 -width 60
+    } else {
+	$w.buttons.send configure -text $t(send)
+	$w.buttons.sendsave configure -text $t(send_save)
+	$w.buttons.address configure -text $t(address)
+    }
+
+    # Pack everything
+     pack $w.buttons.send \
+	$w.buttons.sendsave \
+	$w.buttons.address \
+	-side left -padx 4
+    pack $mh(headerFrame) -side top -fill x -padx 5 -pady 5
+    pack $w.buttons -side top -fill x -padx 25 -pady 5 -ipadx 180
+
+    update idletasks
+#    grid columnconfigure $w.desc 1 -minsize 30
+    Place $w composeBounce
+    focus $first
+}
+
+proc ComposeBounceDone {handler do} {
+    global option t b idCnt activeCompose
+    upvar #0 $handler mh
+
+    RecordPos $mh(w) composeBounce
+    if [winfo exists $mh(oldFocus)] {focus $mh(oldFocus)}
+    focus $mh(w).buttons.send
+    update
+    destroy $mh(w)
+    DoCompose2 dummy $handler $do
+}
 
 # ComposeForwardInline --
 #
@@ -247,8 +416,7 @@ proc ComposeForwardAttachment {fhandler msg} {
 # Choose a message in the hold and continue compose it.
 #
 # Arguments:
-# fhandler  -   The handler for the parent folder window
-proc ComposeHeld {fhandler} {
+proc ComposeHeld {} {
     global idCnt t b defaultFont
 
     # First see if there are any held messages
@@ -296,7 +464,7 @@ proc ComposeHeld {fhandler} {
 
     if {1 == $hd(done)} {
 	if [string length $index] {
-	    return [ComposeExtracted $fhandler [RatHold extract $index]]
+	    return [ComposeExtracted [RatHold extract $index]]
 	} else {
 	    Popup $t(must_select)
 	}
@@ -310,9 +478,8 @@ proc ComposeHeld {fhandler} {
 # Starts composing an extracted message
 #
 # Arguments:
-# fhandler  -   The handler for the parent folder window
 # mgh - handler of the extracted message
-proc ComposeExtracted {fhandler mgh} {
+proc ComposeExtracted {mgh} {
     upvar #0 $mgh mh
     if [info exists mh(body)] {
 	upvar #0 $mh(body) bh
@@ -347,7 +514,7 @@ proc ComposeExtracted {fhandler mgh} {
 	set mh(attachmentList) $children
     }
     set mh(whence) held
-    return [DoCompose $mgh $fhandler 0 0]
+    return [DoCompose $mgh dummy 0 0]
 }
 
 # DoCompose --
@@ -371,7 +538,7 @@ proc DoCompose {handler fhandler edit_text add_sig} {
     set mh(win_type) compose
 
     # If there is no folder window parent, set some defaults
-    if ![string compare $fhandler dummy] {
+    if { 0 == [string compare $fhandler dummy]} {
 	set fh(from) $option(from)
 	set fh(reply_to) $option(reply_to)
 	set fh(signature) $option(signature)
@@ -387,6 +554,12 @@ proc DoCompose {handler fhandler edit_text add_sig} {
     foreach i $vars {
 	set mh(O_$i) 1
     }
+    regsub -all -- - [string tolower $option(custom_headers)] _ vars
+    foreach i $vars {
+	set mh(O_$i) 1
+	set t($i) $i
+    }
+
     set mh(request_dsn) $option(dsn_request)
     if {![info exists mh(from)] || ![string length $mh(from)]} {
 	set mh(from) $fh(from)
@@ -466,13 +639,6 @@ proc DoCompose {handler fhandler edit_text add_sig} {
     set b($w.buttons.forward) forward_inline
     lappend mh(edit_block) $w.buttons.forward
 
-    # The spell check button
-#     button $w.buttons.spell -takefocus 0 \
-# 	-command "Ispell_CheckEntireWindow $w.body.text" \
-# 	-highlightthickness 0 -anchor center
-#     set b($w.buttons.spell) spell
-#     lappend mh(edit_block) $w.buttons.spell
-
     # the attach and detach buttons
     frame $w.buttons.adtch
     # The attachment button
@@ -494,7 +660,6 @@ proc DoCompose {handler fhandler edit_text add_sig} {
 	$w.buttons.address configure -image addrbut -height 60 -width 60
 	$w.buttons.reply configure -image repbut -height 60 -width 60
 	$w.buttons.forward configure -image fwrdbut -height 60 -width 60
-#	$w.buttons.spell configure -image spllbut -height 60 -width 60
 	$w.buttons.attachf configure -image atchbut -height 26 -width 60
 	$w.buttons.detach configure -image dtchbut -height 26 -width 60
     } else {
@@ -503,22 +668,85 @@ proc DoCompose {handler fhandler edit_text add_sig} {
 	$w.buttons.address configure -text $t(address)
 	$w.buttons.reply configure -text $t(reply)
 	$w.buttons.forward configure -text $t(forward)
-#	$w.buttons.spell configure -text $t(spell_check)
 	$w.buttons.attachf configure -text $t(attach)
 	$w.buttons.detach configure -text $t(detach)
     }
     
-    # The PGP lock button
+    # The PGP and DSN buttons
+    frame $w.buttons.pgpdsn
     if $option(pgp_enable) {
 	button $w.buttons.key -takefocus 0 -command "AttachKeys $handler" \
 	    -anchor center
 	set b($w.buttons.key) attach_keys
+	button $w.buttons.recp -takefocus 0 \
+	    -command "PostReqDSN $handler" -anchor center
+	set b($w.buttons.recp) request_notification
 	if $option(image_buttons) {
-	    $w.buttons.key configure -image lockbut -height 60 -width 60
+	    $w.buttons.key configure -image mlockbut -height 26 -width 60
+	    $w.buttons.recp configure -image mrecpbut -height 26 -width 60
 	} else {
 	    $w.buttons.key configure -text $t(attach_pgp_keys)...
+	    $w.buttons.recp configure -text $t(request_notification)
 	}
-    }
+	pack $w.buttons.key $w.buttons.recp -in $w.buttons.pgpdsn \
+	   -pady 2 -fill x -side top 
+	if {$option(pgp_sign) == 1 && $option(pgp_encrypt) == 1} {
+	    set pgpbut 0
+	} elseif {$option(pgp_sign) && $option(pgp_encrypt) == 0} {
+	    frame $w.buttons.pgpfr
+	    button $w.buttons.crypt -takefocus 0 \
+		-command "PostPGPCrypt $handler" -anchor center
+	    set b($w.buttons.crypt) pgp_encrypt
+	    if $option(image_buttons) {
+		$w.buttons.crypt configure -image cryptbut -height 60 \
+		    -width 60
+	    } else {
+		$w.buttons.crypt configure -text $t(pgp_encrypt)
+	    }
+	    pack $w.buttons.crypt -in $w.buttons.pgpfr
+	} elseif {$option(pgp_sign) == 0 && $option(pgp_encrypt)} {
+	    frame $w.buttons.pgpfr
+	    button $w.buttons.sign -takefocus 0 \
+		-command "PostPGPSign $handler" -anchor center
+	    set b($w.buttons.sign) pgp_sign
+	    if $option(image_buttons) {
+		$w.buttons.sign configure -image signbut -height 60 \
+		    -width 60
+	    } else {
+		$w.buttons.sign configure -text $t(pgp_sign)
+	    }
+	    pack $w.buttons.sign -in $w.buttons.pgpfr
+	} else {
+	    frame $w.buttons.pgpfr
+	    button $w.buttons.crypt -takefocus 0 \
+		-command "PostPGPEncrypt $handler" -anchor center
+	    set b($w.buttons.crypt) pgp_encrypt
+	    button $w.buttons.sign -takefocus 0 \
+		-command "PostPGPSign $handler" -anchor center
+	    set b($w.buttons.sign) pgp_sign
+	    if $option(image_buttons) {
+		$w.buttons.crypt configure -image mcryptbut -height 26 \
+		    -width 60
+		$w.buttons.sign configure -image msignbut -height 26 \
+		    -width 60
+	    } else {
+		$w.buttons.sign configure -text $t(pgp_sign)
+		$w.buttons.crypt configure -text $t(pgp_encrypt)
+	    }
+	    pack $w.buttons.sign $w.buttons.crypt -in $w.buttons.pgpfr \
+		-pady 2 -fill x -side top
+	}
+    } else {
+	button $w.buttons.recp -takefocus 0 \
+	    -command "PostReqDSN $handler" -anchor center
+	set b($w.buttons.recp) request_notification
+	if $option(image_buttons) {
+	    $w.buttons.recp configure -image recpbut -height 60 -width 60
+	} else {
+	    $w.buttons.recp configure -text $t(request_notification)
+	}
+	pack $w.buttons.recp -in $w.buttons.pgpdsn -pady 2 -fill x -side top 
+    }	
 
     # Pack everything
     pack $w.buttons.attachf $w.buttons.detach -in $w.buttons.adtch \
@@ -529,10 +757,11 @@ proc DoCompose {handler fhandler edit_text add_sig} {
 	$w.buttons.reply \
 	$w.buttons.forward \
 	$w.buttons.adtch \
+	$w.buttons.pgpdsn \
 	-side left -padx 4
-    if $option(pgp_enable) { pack $w.buttons.key -side left -padx 4 }
-
-#	$w.buttons.spell 
+    if {$option(pgp_enable) && [winfo exists $w.buttons.pgpfr]} {
+	pack $w.buttons.pgpfr -side left -padx 4
+    }
 
     # Message body
     frame $w.body -relief sunken -bd 2
@@ -679,7 +908,9 @@ proc DoCompose {handler fhandler edit_text add_sig} {
     # Populate headerlist and pack everything
     set first [ComposeBuildHeaderEntries $handler]
     pack $mh(headerFrame) -side top -fill x -padx 5 -pady 5
-    pack $w.buttons -side top -fill x -padx 25 -pady 5
+    if $option(button_bar) {
+	pack $w.buttons -side top -fill x -padx 25 -pady 5
+    }
     pack $w.attach -side bottom -fill x -padx 5 -pady 5
     pack $w.body -expand yes -fill both -padx 8 -pady 5
 
@@ -698,7 +929,7 @@ proc DoCompose {handler fhandler edit_text add_sig} {
     bind $mh(composeBody) <Destroy> "DoCompose2 $w $handler abort"
     bind $mh(headerFrame).subject_entry <FocusOut> "SetTitle $handler mh subject"
 
-    if ![string compare $fhandler dummy] {
+    if { 0 == [string compare $fhandler dummy]} {
 	$w.buttons.reply configure -state disabled
 	$w.buttons.forward configure -state disabled
     }
@@ -721,7 +952,6 @@ proc DoCompose2 {w handler do} {
     if {0 == [info exists mh(closing)] && 1 == $mh(closing)} {
 	return
     }
-
     # Check if A save folder is defined
     if ![string length $mh(save_to)] {
 	if {[info exists fh(save_to)] && [string length $fh(save_to)] \
@@ -740,7 +970,7 @@ proc DoCompose2 {w handler do} {
 	set mh(closing) 1
 	# By moving the focus to the text wiget we force all HeaderEntries
 	# to update their variables
-	focus $mh(composeBody)
+	if [winfo exists $mh(composeBody)] { focus $mh(composeBody) }
 	update
 
 	# Check for good hostname
@@ -749,20 +979,20 @@ proc DoCompose2 {w handler do} {
 	    bell $mh(toplevel)
 	    return
 	}
-	wm withdraw $w
+	if [winfo exists $w] {wm withdraw $w}
 	if ![ComposeSend $handler] {
 	    set sent 1
 	    set doRemove 0
-	    if $mh(answer) {
+	    if { ![catch {info exists $fh(folder_handler)}] && $mh(answer)} {
 		set index [$fh(folder_handler) find $mh(curmsg)]
 		if { -1 != $index } {
 		    if ![$fh(folder_handler) getFlag $index answered] {
 			SetFlag $mh(parent) answered 1 $index
-		    }
+			}
 		}
 	    }
 	} else {
-	    wm deiconify $w
+	    if [winfo exists $w] {wm deiconify $w}
 	    set mh(closing) 0
 	    return
 	}
@@ -778,15 +1008,16 @@ proc DoCompose2 {w handler do} {
     }
     set index [lsearch $composeWindowList $handler]
     set composeWindowList [lreplace $composeWindowList $index $index]
-    if [winfo exists $w] {
+    if { 0 != [string compare $w dummy]} {
 	RecordPos $w compose
 	RecordSize $mh(composeBody) compose
 	bind $mh(composeBody) <Destroy> { }
 	foreach bn [array names b $w.*] {unset b($bn)}
 	if !{$quiting} {ConfigMainMenu default}
+	destroy ${w}_icon
 	destroy $w
 	set activeCompose ""
-	focus $mh(oldFocus)
+	if [winfo exists $mh(oldFocus)] {focus $mh(oldFocus)}
     }
     if [string length [array names mh splwin]] {
 	tkisp_quit $mh(splwin) $mh(composeBody)
@@ -1052,7 +1283,7 @@ proc ComposeBind {handler} {
 	    $mh(file_menu)
 
 	# Make sure the buttons are correct.
-	if [info exists mh(whence)] {
+	if { $mh(whence) == "forward" || $mh(whence) == "reply"} {
 	    $mh(toplevel).buttons.forward configure -state disabled
 	    $mh(toplevel).buttons.reply configure -state disabled
 	    RatBind $w compose_key_replys {}
@@ -1093,6 +1324,12 @@ proc RatSendSavePostMenu {w m handler} {
 proc RatSendSaveDo {w handler save_to} {
     upvar #0 $handler hd
 
+    if { 0 == [string compare $hd(whence) bounce]} {
+	RecordPos $hd(w) composeBounce
+	if [winfo exists $hd(oldFocus)] {focus $hd(oldFocus)}
+	destroy $hd(w)
+	set w dummy
+    }
     if [string length $save_to] {
 	set hd(save_to) $save_to
 	DoCompose2 $w $handler send
@@ -1106,7 +1343,8 @@ proc RatSendSaveDo {w handler save_to} {
 # Arguments:
 # handler -	The handler for the active compose session
 proc ComposeBuildHeaderEntries {handler} {
-    global composeHeaderList composeAdrHdrList t b defaultFont option
+    global composeHeaderList composeAdrHdrList t b defaultFont option \
+	bounceHeaderList
     upvar #0 $handler mh
 
     foreach slave [grid slaves $mh(headerFrame)] {
@@ -1116,7 +1354,16 @@ proc ComposeBuildHeaderEntries {handler} {
     set row 0
     grid columnconfigure $mh(headerFrame) 1 -weight 1
 
-    foreach header $composeHeaderList {
+    if ![string compare $mh(whence) bounce] {
+	set headers $bounceHeaderList
+    } else {
+	set headers $composeHeaderList
+    }
+
+    # add any user defined headers
+#    lappend headers [string tolower $option(custom_headers)]
+
+    foreach header $headers {
 	if {0 == $mh(O_$header)} {
 	    continue
 	}
@@ -1155,12 +1402,15 @@ proc ComposeBuildStruct {handler} {
     # Create identifier
     set id body[incr idCnt]
     upvar #0 $id bh
-
     set bh(type) text
     set bh(subtype) plain
     set bh(filename) [RatTildeSubst $option(send_cache)/rat.[RatGenId]]
     set fh [open $bh(filename) w 0600]
-    puts -nonewline $fh [$mh(composeBody) get 0.0 end]
+    if ![string compare $mh(whence) bounce] {
+	puts -nonewline $fh $mh(data)
+    } else {
+	puts -nonewline $fh [$mh(composeBody) get 0.0 end]
+    }
     close $fh
     set bh(encoding) [RatGetEncoding $bh(filename)]
     if { "7bit" != $bh(encoding) } {
@@ -1228,7 +1478,7 @@ proc ComposeSend {handler} {
 	    }
 	}
     }
-
+    
     if [catch "RatSend $option(delivery_mode) $handler" message] {
 	RatLog 4 $message
 	return 1
@@ -1338,7 +1588,7 @@ proc Attach {handler} {
     # Should we continue?
     if { 0 == $hd(done) } {
 	destroy $w
-	focus $oldFocus
+	if [winfo exists $oldFocus] {focus $oldFocus}
 	unset hd
 	return
     }
@@ -1483,7 +1733,7 @@ proc Attach {handler} {
     RecordPos $w attach2
     foreach bn [array names b $w.*] {unset b($bn)}
     destroy $w
-    focus $oldFocus
+    if [winfo exists $oldFocus] {focus $oldFocus}
 }
 
 # DropAttach --
@@ -1507,7 +1757,7 @@ proc DropAttach {handler filename} {
     set type [RatType $hd(filename)]
     set hd(typestring) [lindex $type 0]
     set hd(encoding) [lindex $type 1]
-    set hd(disposition) "attachment ; filename=\"$filelit\""
+    set hd(disposition) "attachment ; filename=\"$filename\""
 
     set type [split $hd(typestring) /]
     set hd(type) [lindex $type 0]
@@ -1535,11 +1785,8 @@ proc DropAttach {handler filename} {
 	}
     }
     lappend mh(attachmentList) $id
-    if { "" != $hd(description) } {
-	set desc $hd(description)
-    } else {
-	set desc "$hd(typestring): $hd(filename)"
-    }
+    set desc "$hd(typestring): $hd(filename)"
+    
     if ![catch {info exists $mh(attachmentListWindow)}] {
 	$mh(attachmentListWindow) insert end $desc
     }
@@ -1605,7 +1852,7 @@ proc SubtypeSpec {variable type topwin} {
     RecordPos $w subtypeSpec
     destroy $w
     unset hd
-    focus $oldFocus
+    if [winfo exists $oldFocus] {focus $oldFocus}
 }
 
 # AttachKeys --
@@ -1639,6 +1886,7 @@ proc AttachKeysDo {handler ids} {
 	close $f
 	lappend mh(attachmentList) $id
 	$mh(attachmentListWindow) insert end $hd(description)
+	$mh(toplevel).buttons.key configure -state disabled
     }
 }
 
@@ -1747,7 +1995,7 @@ proc ComposeHold {mainW handler} {
     }
 
     RecordPos $w composeHold
-    catch {focus $oldFocus}
+    if [winfo exists $oldFocus] {focus $oldFocus}
     unset b($w.desc.entry)
     destroy $w
     unset hd
@@ -2267,7 +2515,7 @@ proc ComposeUndo {handler} {
     set hd(redoTags) [$hd(composeBody) tag ranges noWrap]
     $hd(composeBody) delete undoStart undoEnd
     $hd(composeBody) insert undoStart $hd(undoText)
-    $hd(composeBody) mark set insert $hd(undoInsert)
+    catch {$hd(composeBody) mark set insert $hd(undoInsert)}
     if [info exists hd(undoTags)] {
 	for {set i 0} {$i < [llength $hd(undoTags)]} {incr i 2} {
 	    $hd(composeBody) tag add noWrap [lindex $hd(undoTags) $i] \
