@@ -38,7 +38,7 @@ set folderWindowList {}
 # Arguments:
 # w -		Window which the folder window should be packed into
 
-proc FolderWindowInit {} {
+proc FolderWindowInit {min} {
     global b t idCnt statusText option defaultFont folderWindowList \
 	   valueFont ratDeferred ratSize activeFolder app
 
@@ -118,8 +118,10 @@ proc FolderWindowInit {} {
     bind $texth(clkcan) <1> "Preferences"
     
     # The mailbox syncronize button
-#     button $w.buttons.update -command "Sync $handler 1" \
-# 	-highlightthickness 0 -relief raised -anchor center
+    if $option(sync_but) {
+	button $w.buttons.update -command "Sync $handler $option(sync_oper)" \
+	    -highlightthickness 0 -relief raised -anchor center
+    }
 
     if $option(image_buttons) {
 	$w.buttons.updown.up configure -image upabut -height 26 -width 60
@@ -128,7 +130,9 @@ proc FolderWindowInit {} {
 	$w.buttons.compose configure -image compbut -height 60 -width 60
 	$w.buttons.mboxes configure -image mvbut -height 60 -width 60
 	$w.buttons.find configure -image fndbut -height 60 -width 60
-#	$w.buttons.update configure -image updbut -height 60 -width 60
+	if $option(sync_but) {
+	    $w.buttons.update configure -image updbut -height 60 -width 60
+	}
     } else {
 	$w.buttons.updown.up configure -text $t(folder_key_prev)
 	$w.buttons.updown.down configure -text $t(folder_key_next)
@@ -136,7 +140,9 @@ proc FolderWindowInit {} {
 	$w.buttons.compose configure -text $t(compose)...
 	$w.buttons.mboxes configure -text $t(mailboxes)
 	$w.buttons.find configure -text $t(find)
-#	$w.buttons.update configure -text $t(folder_key_update)
+	if $option(sync_but) {
+	    $w.buttons.update configure -text $t(folder_key_update)
+	}
     }
 
     pack $w.buttons.updown.up $w.buttons.updown.down \
@@ -159,7 +165,9 @@ proc FolderWindowInit {} {
 	set b($fh(sigbut)) no_sig
     }
 
-#    pack $w.buttons.update -side right -padx 4
+    if $option(sync_but) {
+	pack $w.buttons.update -side right -padx 4
+    }
 
     set b($w.buttons.updown.up) prev_msg
     set b($w.buttons.updown.down) next_msg
@@ -168,9 +176,12 @@ proc FolderWindowInit {} {
     set b($w.buttons.mboxes) mailboxes
     set b($w.buttons.find) find
     set b($texth(clkcan)) clock
-#    set b($w.buttons.update) sync
 
-   # The information part
+    if $option(sync_but) {
+	set b($w.buttons.update) sync
+    }
+
+    # The information part
     frame $w.info -relief flat -bd 1
     label $w.info.messages -textvariable ${handler}(folder_messages) \
         -anchor w -font $valueFont
@@ -194,7 +205,9 @@ proc FolderWindowInit {} {
     set b($w.info.messages) current_folder_nummsg
     set b($w.statustext) status_text
 
-    pack $w.buttons -side top -fill x -padx 25 -pady 5
+    if $option(button_bar) {
+	pack $w.buttons -side top -fill x -padx 25 -pady 5
+    }
     pack $w.info -side top -fill x -padx 5
 
 
@@ -385,12 +398,13 @@ proc FolderWindowInit {} {
     place $w.holder.bottom -anchor sw -x 0 -y 0 -rely 1 \
 	-relheight [expr 1.0 - (($lheight + $mheight) / $hheight)] -relwidth 1
 
-    wm deiconify $w
+    if $min {
+	wm deiconify $w
+    }
     update idletasks
 
     # Do bindings
     bind $w <FocusIn> "ConfigMainMenu $handler; set activeFolder $handler"
-
     bind $fh(text) <Configure> "FolderResize $handler folderM"
     bind $fh(message_list) <Configure> "FolderResize $handler msgList"
     bind $fh(message_list) <1>\
@@ -432,12 +446,15 @@ proc FolderBind {handler} {
     RatBind $fh(w) folder_key_sync	"Sync $handler 1" $fh(sync_menu)
     RatBind $fh(w) folder_key_update    "Sync $handler 0" $fh(update_menu)
     RatBind $fh(w) folder_key_delete    \
-	"SetFlag $handler deleted 1 $option(adv_on_flag)" $fh(delete_menu)
-    RatBind $fh(w) folder_key_undelete  \
-	"SetFlag $handler deleted 0 $option(adv_on_flag)" $fh(undelete_menu)
-    RatBind $fh(w) folder_key_flag	"SetFlag $handler flagged toggle 0"
-    RatBind $fh(w) folder_key_seen	"SetFlag $handler seen toggle 0" \
-	$fh(seen_menu)
+	"SetFlag $handler deleted toggle $option(adv_on_flag)" $fh(delete_menu)
+#     RatBind $fh(w) folder_key_undelete  \
+# 	"SetFlag $handler deleted 0 $option(adv_on_flag)" $fh(undelete_menu)
+    RatBind $fh(w) folder_key_flag	\
+	"SetFlag $handler flagged toggle $option(adv_on_flag)"
+    RatBind $fh(w) folder_key_seen	\
+	"SetFlag $handler seen toggle $option(adv_on_flag)" $fh(seen_menu)
+    RatBind $fh(w) folder_key_ans	\
+	"SetFlag $handler answered toggle $option(adv_on_flag)" $fh(ans_menu)
     RatBind $fh(w) folder_key_next	"FolderNext $handler"
     RatBind $fh(w) folder_key_prev	"FolderPrev $handler"
     RatBind $fh(w) folder_key_home	"ShowHome $fh(text)"
@@ -459,6 +476,8 @@ proc FolderBind {handler} {
     RatBind $fh(w) folder_key_forward_a \
 	"FolderSomeCompse $handler ComposeForwardAttachment" \
 	$fh(forward_a_menu)
+    RatBind $fh(w) folder_key_bounce \
+	"FolderSomeCompse $handler ComposeBounce" $fh(bounce_menu)
     RatBind $fh(w) folder_key_cycle_header "CycleShowHeader $handler"
     RatBind $fh(w) folder_key_find 	"FolderFind $handler" $fh(find_menu)
     RatBind $fh(w) folder_key_select_all "GroupAll $handler" $fh(group_all_menu)
@@ -673,6 +692,10 @@ proc FolderListResize {handler} {
         return
     }
 
+    if ![info exists fh(folder_handler)] {
+	return
+    }
+
     set n [lindex [$fh(folder_handler) info] 1]
     if {0 == $n} {
         return
@@ -871,7 +894,7 @@ proc SetFlag {handler flag value advance {messages {}}} {
 
 proc Quit {handler} {
     global expAfter logAfter ratDeferred ratSenderSending t composeWindowList \
-	folderWindowList activeFolder quiting
+	folderWindowList activeFolder quiting vFolderChanged
 
     if ![string compare $handler all] {
 	set quiting 1
@@ -903,6 +926,9 @@ proc Quit {handler} {
 	    }
 	    RatLog 2 "" explicit
 	}
+	if $vFolderChanged {
+	    VFolderWrite
+	}
 	RatSend kill
 	if [string length $expAfter] {after cancel $expAfter}
 	if [string length $logAfter] {after cancel $logAfter}
@@ -933,9 +959,10 @@ proc Quit {handler} {
     if !{$quiting} {ConfigMainMenu default}
     unset fh
     destroy .$handler .${handler}_icon .${handler}struct
+
     if { [llength [winfo children .]] <=2 } {
 	Quit all
-}
+    }
 }
 
 # Sync --
@@ -962,7 +989,7 @@ proc Sync {handler expunge} {
     }
     set topBefore [lindex [$fh(message_list) yview] 0]
 
-    if [catch {$fh(folder_handler) update $expunge} result] {
+    if [catch {$fh(folder_handler) update $expunge $fh(folder_sort)} result] {
 	RatLog 4 $result
 	Quit $handler
 	return
