@@ -19,13 +19,20 @@
 #  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 set vFolderCut ""
-# CreateMBoxWin --
-#
-# Create a hierachical browser widget to use for mailbox manipulation
-#
-# Arguments:
 proc CreateMBoxWin {} {
-    global option t b vFolderCurrent vFolderChanged hiervfld hierlb mailbox \
+    # CreateMBoxWin --
+    #
+    # Create a hierachical browser widget to use for mailbox manipulation
+    #
+    # @global option : main option database array
+    # @global t : text string array for labels, etc
+    # @global b : text string array for balloon help
+    # @global vFolderCurrent : The currently selected mailbox
+    # @global hiervfld : Flag which indicates the use of a hierarchy
+    # @global hierlb : Path of the first listbox in the widget
+    # @global tk_version : What version of Tk is this
+
+    global option t b vFolderCurrent hiervfld hierlb \
 	tk_version
 
     set id .mailbox
@@ -65,7 +72,6 @@ proc CreateMBoxWin {} {
     upvar #0 $id md
     # Set some global defaults, for now...
     set mypad 8
-    set vFolderChanged 0
     set hiervfld 1
     set hierlb $id.fLBs.0.lb
     set vFolderCurrent {0 end}
@@ -133,6 +139,12 @@ proc CreateMBoxWin {} {
     $menu add command -label $t(set_to_save_outgoing) \
 	-command {VFolderSetToSpecial Save}
     set b($menu,[$menu index end]) vd_setsaveout
+    $menu add command -label $t(set_to_open_on_startup) \
+	-command {VFolderSetToSpecial Startup}
+    set b($menu,[$menu index end]) vd_setstartup
+    $menu add command -label $t(set_to_min_on_startup) \
+	-command {VFolderSetToSpecial Startmin}
+    set b($menu,[$menu index end]) vd_setstartmin
     $menu add command -label $t(create_submenu)... -command VFolderCreateMenu
     set b($menu,[$menu index end]) vd_createsub
     $menu add command -label $t(new_file)... -command {VFolderNew file}
@@ -155,14 +167,18 @@ proc CreateMBoxWin {} {
 }
 
 
-# VFolderBuildList --
-#
-# Constructs a list of vfolders.
-#
-# Arguments:
-# m   -		The listbox in which to insert the entries
-# id  -		The id of the struct to start with
 proc VFolderBuildList {m id} {
+    # VFolderBuildList --
+    #
+    # Constructs a list of vfolders.
+    #
+    # @param m : The listbox in which to insert the entries
+    # @param id : The id of the struct to start with
+    # @global b : text string array for balloon help
+    # @global vFolderStruct : The mailbox hierarchy array
+    # @global vFolderDef : The mailbox definition array
+    # @global vFolderCurrent : The currently selected mailbox
+
     global b vFolderStruct vFolderDef vFolderCurrent
     upvar #0 $m current
 
@@ -207,14 +223,15 @@ proc VFolderBuildList {m id} {
     }
 }
 
-# DynamBuildList --
-#
-# Constructs a list of dynamic folders. 
-#
-# Arguments:
-# m   -		The listbox in which to insert the entries
-# id  -		The id of the dynamic folder to expand
 proc DynamBuildList {m id} {
+    # DynamBuildList --
+    #
+    # Constructs a list of dynamic folders. 
+    #
+    # Arguments:
+    # @param m : The listbox in which to insert the entries
+    # @param id : The id of the dynamic folder to expand
+    # @global vFolderDef : The mailbox definition array
     global vFolderDef
     upvar #0 $m current
 
@@ -230,7 +247,7 @@ proc DynamBuildList {m id} {
 	if [file isfile $f] {
 	    $m insert end [file tail $f]
 	    set current($num) [list [file tail $f] file \
-				   [lindex $vfolder 2] $f]
+				   [lindex $vfolder 2] \"$f\"]
 	    incr num
 	}
     }
@@ -242,17 +259,23 @@ proc DynamBuildList {m id} {
     }
 }
 
-# VFActHeirList --
-#
-# Act upon an event in a hierarchical virtual folder listbox widget
-#
-# Arguments:
-#
-# handler - the handler for this listbox
-# Type      - the type of hierarchy we're dealing with
 proc VFActHierList {handler type} {
+    # VFActHeirList --
+    #
+    # Act upon an event in a hierarchical virtual folder listbox widget
+    #
+    # @param handler : the handler for this listbox
+    # @param type : the type of hierarchy we're dealing with
+    # @global option : main option database array
+    # @global t : text string array for labels, etc
+    # @global vFolderCurrent : The currently selected mailbox
+    # @global vFolderSave : The default mailbox to save outgoing messages
+    # @global vFolderInbox : The default inbox
+    # @global vFolderStruct : The mailbox hierarchy array
+    # @global vFolderDef : The mailbox definition array
+    # @global hierlb : Path of the first listbox in the widget
     global t vFolderCurrent option vFolderStruct vFolderDef \
-	vFolderInbox vFolderSave vFolderChanged hierlb
+	vFolderInbox vFolderSave hierlb
     upvar #0 $type htype
     upvar #0 $handler current
 
@@ -388,9 +411,9 @@ proc VFActHierList {handler type} {
 	if $term {
 	    $but.open configure -state normal -command \
 		"FolderWindowCreate [list $current($itemnum)]"
+	    $but.new configure -state normal
 	    $but.transfer configure -state normal -command \
 		"Transfer"
-	    $but.new configure -state disabled
 	    $but.delete configure -state normal
 	    bind $handler <Double-1> "VFBindHack $handler"
 	} elseif $dynamic {
@@ -401,8 +424,8 @@ proc VFActHierList {handler type} {
 	    bind $handler <Double-1> ""
 	} elseif $struct {
 	    $but.open configure -state disabled
-	    $but.transfer configure -state disabled -command ""
 	    $but.new configure -state normal
+	    $but.transfer configure -state disabled -command ""
 	    $but.delete configure -state normal
 	    bind $handler <Double-1> ""
 	}
@@ -419,19 +442,25 @@ proc VFActHierList {handler type} {
     #    $ggparent.hsb.sb set 1 $num_lbs 0 $htype(highlbnum)
 }
 
-# VFBindHack --
-#
-# A hack to get around bind's expansion of "%" characters
-#
-# Arguments:
-# handler - the handler for the selected listbox
 proc VFBindHack { handler } {
+    # VFBindHack --
+    #
+    # A hack to get around bind's expansion of "%" characters
+    #
+    # @param handler : The handler for the selected listbox
+    # @global activeFolder : The currently selected browser window
+    # @global folderWindowList : The list of all browser windows
+
     global activeFolder folderWindowList
     upvar #0 $handler current
 
+    if ![info exist activeFolder] {
+	set activeFolder {}
+    }
+
     if {![string length $activeFolder] || \
 	    -1 == [lsearch -exact $folderWindowList $activeFolder]} {
-	set activeFolder [FolderWindowInit]
+	set activeFolder [FolderWindowInit 1]
     }
 
     # figure out which item was selected
@@ -441,12 +470,19 @@ proc VFBindHack { handler } {
     focus .$activeFolder
 }
 
-# Transfer --
-#
-# Transfer the selected message(s) to a different mailbox
-#
-# Arguments:
 proc Transfer {{folder {}}} {
+    # Transfer --
+    #
+    # Transfer the selected message(s) to a different mailbox
+    #
+    # @param folder : The mailbox to transfer messages to, if not the currently active one
+    # @global t : text string array for labels, etc
+    # @global vFolderCurrent : The currently selected mailbox
+    # @global vFolderStruct : The mailbox hierarchy array
+    # @global vFolderDef : The mailbox definition array
+    # @global activeFolder : The currently selected browser window
+    # @global folderWindowList : The list of all browser windows
+
     global vFolderStruct vFolderDef activeFolder vFolderCurrent \
 	folderWindowList t
 
@@ -457,6 +493,9 @@ proc Transfer {{folder {}}} {
 	return
     }
     upvar #0 $activeFolder fh
+
+    if [info exist $fh(current)] {return}
+
     # Default to group, if any messages are flagged, else current
     if ![llength [$fh(folder_handler) flagged flagged]] {
 	set a 0
@@ -491,18 +530,29 @@ proc Transfer {{folder {}}} {
     }
 }
 
-# VFolderMakeMenu:
-#
-# Make the menu for the given entry.
-#
-# Arguments:
-# x, y   -	Position of pointer, this is where we will popup the menu
-# listW  -	Name of the list widget the entry belongs to
-# sIdent -	Identifier of the vFolderStruct the entry belongs to
-# index  -	Index in the above mentioned vFolderStruct
 proc VFolderMakeMenu {x y listW sIdent index} {
+    # VFolderMakeMenu:
+    #
+    # Make the menu for the given entry.
+    #
+    # @param x : X Position of pointer, this is where we will popup the menu
+    # @param y : Y Position of pointer, this is where we will popup the menu
+    # @param listW : Name of the list widget the entry belongs to
+    # @param sIdent : Identifier of the vFolderStruct the entry belongs to
+    # @param index : Index in the above mentioned vFolderStruct
+    # @global t : text string array for labels, etc
+    # @global vFolderCurrent : The currently selected mailbox
+    # @global vFolderSave : The default mailbox to save outgoing messages
+    # @global vFolderInbox : The default inbox
+    # @global vFolderStartup : A list of mailboxes to be opened at startup
+    # @global vFolderStartmin : A list of mailboxes to be opened minimized at startup
+    # @global vFolderCut : The ID of any cut mailbox
+    # @global vFolderStruct : The mailbox hierarchy array
+    # @global vFolderDef : The mailbox definition array
+    # @global hierlb : Path of the first listbox in the widget
+
     global vFolderCurrent vFolderStruct vFolderInbox vFolderSave t hierlb \
-	vFolderCut
+	vFolderCut vFolderStartup vFolderStartmin
 
     set w [winfo toplevel $listW]
     set hierlb $listW
@@ -539,6 +589,23 @@ proc VFolderMakeMenu {x y listW sIdent index} {
 		    -label $t(set_to_save_outgoing) -state disabled
 	    }
 	}
+	if ![lsearch -exact $vFolderStartup [lindex $elem 1]] {
+	    $w.m entryconfigure 6 \
+		-label $t(unset_to_open_on_startup) -state normal
+	    $w.m entryconfigure 7 \
+		-label $t(set_to_min_on_startup) -state disabled
+	} elseif ![lsearch -exact $vFolderStartmin [lindex $elem 1]] {
+	    $w.m entryconfigure 6 \
+		-label $t(set_to_open_on_startup) -state disabled
+	    $w.m entryconfigure 7 \
+		-label $t(unset_to_min_on_startup) -state normal
+	} else {
+	    $w.m entryconfigure 6 \
+		-label $t(set_to_open_on_startup) -state normal
+	    $w.m entryconfigure 7 \
+		-label $t(set_to_min_on_startup) -state normal
+	}
+	    
 	if [string length $vFolderCut] {
 	    $w.m entryconfigure 2 -state disabled
 	    $w.m entryconfigure 3 -state normal
@@ -554,17 +621,20 @@ proc VFolderMakeMenu {x y listW sIdent index} {
     }
 }
 
-# MBVMakeMenu:
-#
-# Make the menu for the given entry in the MailboxView window.
-#
-# Arguments:
-# x, y   -	Position of pointer, this is where we will popup the menu
-# listW  -	Name of the list widget the entry belongs to
-# sIdent -	Identifier of the vFolderStruct the entry belongs to
-# index  -	Index in the above mentioned vFolderStruct
 proc MBVMakeMenu {x y listW sIdent index} {
-    global vFolderStruct vFolderDef t
+    # MBVMakeMenu:
+    #
+    # Make the menu for the given entry in the MailboxView window.
+    #
+    # @param x : X Position of pointer, this is where we will popup the menu
+    # @param y : Y Position of pointer, this is where we will popup the menu
+    # @param listW : Name of the list widget the entry belongs to
+    # @param sIdent : Identifier of the vFolderStruct the entry belongs to
+    # @param index : Index in the above mentioned vFolderStruct
+    # @global vFolderStruct : The mailbox hierarchy array
+    # @global vFolderDef : The mailbox definition array
+    # @global t : text string array for labels, etc
+   global vFolderStruct vFolderDef t
 
     set w [winfo parent [winfo parent [winfo parent $listW]]]
 #    set hierlb $listW
@@ -604,14 +674,19 @@ proc MBVMakeMenu {x y listW sIdent index} {
     }
 }
 
-# VFHierWindowDestroy --
-#
-# This procedure is called when the vfolder hier window is destroyed. It
-# writes any changes to the vfolder structure to disk, if needed.
-#
-# Arguments:
-# id  - the id for this window
 proc VFHierWindowDestroy {id} {
+    # VFHierWindowDestroy --
+    #
+    # This procedure is called when the vfolder hier window is destroyed. It
+    # writes any changes to the vfolder structure to disk, if needed.
+    #
+    # @param id : the id for this window
+    # @global vFolderCut : The ID of any cut mailbox
+    # @global vFolderChanged : Whether or not the mailbox has changed
+    # @global t : text string array for labels, etc
+    # @global hiervfld : Flag which indicates the use of a hierarchy
+    # @global quiting : Flag which indicates that the application is closing
+    # @global ratPlace : Array which holds window placement data
     global vFolderChanged hiervfld vFolderCut t quiting ratPlace
     upvar $id handler
 
@@ -636,13 +711,13 @@ proc VFHierWindowDestroy {id} {
     }
 }
 
-# FolderWindow Create --
-#
-# This procedure is called to create a new folder window
-#
-# Arguments:
-# folder - the folder to open
 proc FolderWindowCreate {folder} {
+    # FolderWindow Create --
+    #
+    # This procedure is called to create a new folder window
+    #
+    # @param folder : the folder to open
+    # @global folderWindowList : The list of all browser windows
     global folderWindowList
 
     foreach handler $folderWindowList {
@@ -655,7 +730,7 @@ proc FolderWindowCreate {folder} {
 	    }
 	}
     }
-    set handler [FolderWindowInit]
+    set handler [FolderWindowInit 1]
     VFolderOpen $handler $folder
     focus .$handler
 }
