@@ -33,7 +33,6 @@ proc CreateMainMenu {{handler ""}} {
 	set w [menu .menu -tearoff 1 -title Postilion]
     } else {
 	upvar #0 $handler wh
-#       .f1.#f1#menubar.#f1#menubar#mbox.#f1#menubar#mbox#new
 	set ptop $wh(w).#$handler#menubar
 	set w [set wh(menubar) [menu $wh(w).menubar -relief flat -bd 0]]
 	$wh(w) configure -menu $w
@@ -201,8 +200,7 @@ proc CreateMainMenu {{handler ""}} {
 	set b($p,[$m index end]) sort_order
 	menu $m.sort -tearoff 1 -title $t(sort_order)
 	set mmenu(mbox-sort) $m.sort
-	$m.sort add radiobutton -label $t(subject_by_date) \
-	    -variable option(folder_sort) -value subject
+	$m.sort add radiobutton -label $t(subject_by_date)
 	set mmenu(mbox-sort-subjectbydate) [$m.sort index end]
 	if $option(next_menu) { 
 	    set p $ptop.#menu#mbox.#menu#mbox#sort
@@ -210,28 +208,22 @@ proc CreateMainMenu {{handler ""}} {
 	    set p $ptop.#$handler#menubar#mbox.#$handler#menubar#mbox#sort
 	}
 	set b($p,[$m.sort index end]) sort_subjdate
-	$m.sort add radiobutton -label $t(subjectonly) \
-	    -variable option(folder_sort) -value subjectonly
+	$m.sort add radiobutton -label $t(subjectonly)
 	set mmenu(mbox-sort-subjectonly) [$m.sort index last]
 	set b($p,[$m.sort index end]) sort_subj
-	$m.sort add radiobutton -label $t(bysender) \
-	    -variable option(folder_sort) -value sender 
+	$m.sort add radiobutton -label $t(bysender)
 	set mmenu(mbox-sort-bysender) [$m.sort index end]
 	set b($p,[$m.sort index end]) sort_sender
-	$m.sort add radiobutton -label $t(natural_order) \
-	    -variable option(folder_sort) -value folder
+	$m.sort add radiobutton -label $t(natural_order)
 	set mmenu(mbox-sort-natural) [$m.sort index end]
 	set b($p,[$m.sort index end]) sort_natural
-	$m.sort add radiobutton -label $t(reverse_natural_order) \
-	    -variable option(folder_sort) -value reverseFolder
+	$m.sort add radiobutton -label $t(reverse_natural_order)
 	set mmenu(mbox-sort-rev_natural) [$m.sort index end]
 	set b($p,[$m.sort index end]) sort_reverse_natural
-	$m.sort add radiobutton -label $t(by_date) \
-	    -variable option(folder_sort) -value date
+	$m.sort add radiobutton -label $t(by_date)
 	set mmenu(mbox-sort-bydate) [$m.sort index end]
 	set b($p,[$m.sort index end]) sort_date
-	$m.sort add radiobutton -label $t(reverse_date) \
-	    -variable option(folder_sort) -value reverseDate 
+	$m.sort add radiobutton -label $t(reverse_date)
 	set mmenu(mbox-sort-rev_date) [$m.sort index end]
 	set b($p,[$m.sort index end]) sort_reversedate
 	if $option(next_menu) { 
@@ -291,6 +283,9 @@ proc CreateMainMenu {{handler ""}} {
 	$m add command -label $t(forward_as_attachment)... -state disabled
 	set mmenu(msg-fwd_attach) [$m index end]
 	set b($p,[$m index end]) forward_attached
+	$m add command -label $t(bounce)... -state disabled
+	set mmenu(msg-bounce) [$m index end]
+	set b($p,[$m index end]) bounce
 	$m add command -label $t(extract_adr)... 
 	set mmenu(msg-extract) [$m index end]
 	set b($p,[$m index end]) extract_adr
@@ -302,15 +297,18 @@ proc CreateMainMenu {{handler ""}} {
 	$m add command -label $t(flag_seen) -state disabled
 	set mmenu(msg-seen) [$m index end]
 	set b($p,[$m index end]) flag_seen
-	$m add command -label $t(flag_unseen) -state disabled
-	set mmenu(msg-unseen) [$m index end]
-	set b($p,[$m index end]) flag_unseen
+# 	$m add command -label $t(flag_unseen) -state disabled
+# 	set mmenu(msg-unseen) [$m index end]
+# 	set b($p,[$m index end]) flag_unseen
+	$m add command -label $t(flag_ans) -state disabled
+	set mmenu(msg-ans) [$m index end]
+	set b($p,[$m index end]) flag_ans
 	$m add command -label $t(delete) -state disabled
 	set mmenu(msg-del) [$m index end]
 	set b($p,[$m index end]) delete
-	$m add command -label $t(undelete) -state disabled
-	set mmenu(msg-undel) [$m index end]
-	set b($p,[$m index end]) undelete
+# 	$m add command -label $t(undelete) -state disabled
+# 	set mmenu(msg-undel) [$m index end]
+# 	set b($p,[$m index end]) undelete
 	$m add command -label $t(print) -state disabled
 	set mmenu(msg-print) [$m index end]
 	set b($p,[$m index end]) print
@@ -358,15 +356,18 @@ proc CreateMainMenu {{handler ""}} {
 	$m add command -label $t(flag_seen) -state disabled
 	set mmenu(group-seen) [$m index end]
 	set b($p,[$m index end]) seen_group
-	$m add command -label $t(flag_unseen) -state disabled
-	set mmenu(group-unseen) [$m index end]
-	set b($p,[$m index end]) unseen_group
+# 	$m add command -label $t(flag_unseen) -state disabled
+# 	set mmenu(group-unseen) [$m index end]
+# 	set b($p,[$m index end]) unseen_group
+	$m add command -label $t(flag_ans) -state disabled
+	set mmenu(group-ans) [$m index end]
+	set b($p,[$m index end]) ans_group
 	$m add command -label $t(delete) -state disabled
 	set mmenu(group-del) [$m index end]
 	set b($p,[$m index end]) delete_group
-	$m add command -label $t(undelete) -state disabled
-	set mmenu(group-undel) [$m index end]
-	set b($p,[$m index end]) undelete_group
+# 	$m add command -label $t(undelete) -state disabled
+# 	set mmenu(group-undel) [$m index end]
+# 	set b($p,[$m index end]) undelete_group
 	$m add command -label $t(print) -state disabled
 	set mmenu(group-print) [$m index end]
 	set b($p,[$m index end]) print_group
@@ -391,8 +392,8 @@ proc CreateMainMenu {{handler ""}} {
     if $showmenu {
 	set m [menu $w.comp -tearoff 1 -title $t(compose)]
 	set mmenu(comp) $m
-	$m add cascade -label Drafts -menu $m.draft
-	menu $m.draft -tearoff 1 -title Drafts
+	$m add cascade -label $t(drafts) -menu $m.draft
+	menu $m.draft -tearoff 1 -title $t(drafts)
 	set mmenu(comp-draft) $m.draft
 	$m.draft add command -label $t(hold)... -state disabled
 	set mmenu(comp-draft-save) [$m.draft index end]
@@ -402,7 +403,7 @@ proc CreateMainMenu {{handler ""}} {
 	    set p $ptop.#$handler#menubar#comp.#$handler#menubar#comp#draft
 	}
 	set b($p,[$m.draft index end]) hold
-	$m.draft add command -label $t(getheld)... -command "ComposeHeld dummy"
+	$m.draft add command -label $t(getheld)... -command "ComposeHeld"
 	set b($p,[$m.draft index end]) compose_held
 	set mmenu(comp-draft-restore) [$m.draft index end]
 	if $option(next_menu) { 
@@ -410,6 +411,14 @@ proc CreateMainMenu {{handler ""}} {
 	} else {
 	    set p $ptop.#$handler#menubar#comp
 	}
+	$m add command -label $t(send) -state disabled
+	set mmenu(comp-send) [$m index end]
+	set b($p,[$m index end]) send
+	$m add cascade -label $t(send_save) -menu $m.sendsave -state disabled
+	menu $m.sendsave -title $t(send_save)
+	set mmenu(comp-sendsave) [$m index end]
+	set mmenu(comp-send_save) $m.sendsave
+	set b($p,[$m index end]) sendsave
 	$m add command -label $t(insert_file)... -state disabled
 	set mmenu(comp-file) [$m index end]
 	set b($p,[$m index end]) compose_insert_file
@@ -617,19 +626,26 @@ proc ConfigMainMenu {handler} {
 		-variable ${handler}(browse)
 	    $mmenu(mbox) entryconfigure $mmenu(mbox-sortorder) -state normal
 	    $mmenu(mbox-sort) entryconfigure $mmenu(mbox-sort-subjectbydate) \
-		-command "Sync $handler 0"
+		-command "Sync $handler 0" -variable ${handler}(folder_sort) \
+		-value subject
 	    $mmenu(mbox-sort) entryconfigure $mmenu(mbox-sort-subjectonly) \
-		-command "Sync $handler 0"
+		-command "Sync $handler 0" -variable ${handler}(folder_sort) \
+		-value subjectonly
 	    $mmenu(mbox-sort) entryconfigure $mmenu(mbox-sort-bysender) \
-		-command "Sync $handler 0"
+		-command "Sync $handler 0" -variable ${handler}(folder_sort) \
+		-value sender
 	    $mmenu(mbox-sort) entryconfigure $mmenu(mbox-sort-natural) \
-		-command "Sync $handler 0"
+		-command "Sync $handler 0" -variable ${handler}(folder_sort) \
+		-value folder
 	    $mmenu(mbox-sort) entryconfigure $mmenu(mbox-sort-rev_natural) \
-		-command "Sync $handler 0"
+		-command "Sync $handler 0" -variable ${handler}(folder_sort) \
+		-value reverseFolder
 	    $mmenu(mbox-sort) entryconfigure $mmenu(mbox-sort-bydate) \
-		-command "Sync $handler 0"
+		-command "Sync $handler 0" -variable ${handler}(folder_sort) \
+		-value date
 	    $mmenu(mbox-sort) entryconfigure $mmenu(mbox-sort-rev_date) \
-		-command "Sync $handler 0"
+		-command "Sync $handler 0" -variable ${handler}(folder_sort) \
+		-value reverseDate
 	    $mmenu(mbox) entryconfigure $mmenu(mbox-compact) \
 		-command "Sync $handler 1" -state normal
 	    set wh(sync_menu) [list $mmenu(mbox) $mmenu(mbox-compact)]
@@ -670,6 +686,11 @@ proc ConfigMainMenu {handler} {
 		-state normal
 	    lappend wh(message_menu_nokeep) $mmenu(msg-fwd_attach)
 	    set wh(forward_a_menu) [list $mmenu(msg) $mmenu(msg-fwd_attach)]
+	    $mmenu(msg) entryconfigure $mmenu(msg-bounce) \
+		-command "FolderSomeCompse $handler ComposeBounce" \
+		-state normal
+	    lappend wh(message_menu_nokeep) $mmenu(msg-bounce)
+	    set wh(bounce_menu) [list $mmenu(msg) $mmenu(msg-bounce)]
 	    $mmenu(msg) entryconfigure $mmenu(msg-extract) \
 		-command "AliasExtract $handler; focus $wh(w)" -state normal
 	    lappend wh(message_menu_nokeep) $mmenu(msg-extract)
@@ -678,24 +699,27 @@ proc ConfigMainMenu {handler} {
 	    $mmenu(msg-move) configure -postcommand \
 		"PostMove $handler current $mmenu(msg-move); focus $wh(w)"
 	    $mmenu(msg) entryconfigure $mmenu(msg-seen) -state normal \
-		-command "SetFlag $handler seen 1 $option(adv_on_flag); focus $wh(w)"
+		-command "SetFlag $handler seen toggle $option(adv_on_flag); focus $wh(w)"
 	    set wh(seen_menu) [list $mmenu(msg) $mmenu(msg-seen)]
 	    lappend wh(message_menu_nokeep) $mmenu(msg-seen)
-	    $mmenu(msg) entryconfigure $mmenu(msg-unseen) -state normal \
-		-command "SetFlag $handler seen 0 $option(adv_on_flag); focus $wh(w)"
-	    set wh(unseen_menu) [list $mmenu(msg) $mmenu(msg-unseen)]
-	    lappend wh(message_menu_nokeep) $mmenu(msg-unseen)
+# 	    $mmenu(msg) entryconfigure $mmenu(msg-unseen) -state normal \
+# 		-command "SetFlag $handler seen 0 $option(adv_on_flag); focus $wh(w)"
+# 	    set wh(unseen_menu) [list $mmenu(msg) $mmenu(msg-unseen)]
+# 	    lappend wh(message_menu_nokeep) $mmenu(msg-unseen)
+	    $mmenu(msg) entryconfigure $mmenu(msg-ans) -state normal \
+		-command "SetFlag $handler answered toggle $option(adv_on_flag); focus $wh(w)"
+	    set wh(ans_menu) [list $mmenu(msg) $mmenu(msg-ans)]
+	    lappend wh(message_menu_nokeep) $mmenu(msg-ans)
 	    $mmenu(msg) entryconfigure $mmenu(msg-del) -state normal \
-		-command "SetFlag $handler deleted 1 $option(adv_on_flag); focus $wh(w)"
+		-command "SetFlag $handler deleted toggle $option(adv_on_flag); focus $wh(w)"
 	    set wh(delete_menu) [list $mmenu(msg) $mmenu(msg-del)]
 	    lappend wh(message_menu_nokeep) $mmenu(msg-del)
-	    $mmenu(msg) entryconfigure $mmenu(msg-undel) -state normal \
-		-command "SetFlag $handler deleted 0 $option(adv_on_flag); focus $wh(w)"
-	    set wh(undelete_menu) [list $mmenu(msg) $mmenu(msg-undel)]
-	    lappend wh(message_menu_nokeep) $mmenu(msg-undel)
+# 	    $mmenu(msg) entryconfigure $mmenu(msg-undel) -state normal \
+# 		-command "SetFlag $handler deleted 0 $option(adv_on_flag); focus $wh(w)"
+# 	    set wh(undelete_menu) [list $mmenu(msg) $mmenu(msg-undel)]
+# 	    lappend wh(message_menu_nokeep) $mmenu(msg-undel)
 	    $mmenu(msg) entryconfigure $mmenu(msg-print) -state normal \
 		-command "Print $handler current; focus $wh(w)"
-	    lappend wh(message_menu_nokeep) $mmenu(msg-undel)
 	    $mmenu(msg) entryconfigure $mmenu(msg-hdr_all) -state normal \
 		-variable $wh(text)(show_header) -value all \
 		-command "FolderSelect $handler \
@@ -729,19 +753,23 @@ proc ConfigMainMenu {handler} {
 		-state normal -command "GroupClear $handler; focus $wh(w)"
 	    set wh(group_clear_menu) [list $mmenu(group) $mmenu(group-clear)]
 	    $mmenu(group) entryconfigure $mmenu(group-seen) -state normal \
-		-command "SetFlag $handler seen 1 0 \
+		-command "SetFlag $handler seen toggle 0 \
                 \[\$${handler}(folder_handler) flagged flagged\]; focus $wh(w)"
-	    $mmenu(group) entryconfigure $mmenu(group-unseen) -state normal \
-		-command "SetFlag $handler seen 0 0 \
+#	    $mmenu(group) entryconfigure $mmenu(group-unseen) -state normal \
+#		-command "SetFlag $handler seen 0 0 \
+#               \[\$${handler}(folder_handler) flagged flagged\]; focus $wh(w)"
+	    $mmenu(group) entryconfigure $mmenu(group-ans) -state normal \
+		-command "SetFlag $handler answered toggle 0 \
                 \[\$${handler}(folder_handler) flagged flagged\]; focus $wh(w)"
 	    $mmenu(group) entryconfigure $mmenu(group-del) -state normal \
-		-command "SetFlag $handler deleted 1 0 \
-                \[\$${handler}(folder_handler) flagged flagged\]; focus $wh(w)"
-	    $mmenu(group) entryconfigure $mmenu(group-undel) -state normal \
-		-command "SetFlag $handler deleted 0 0 \
+		-command "SetFlag $handler deleted toggle 0 \
                 \[\$${handler}(folder_handler) flagged flagged\]; focus $wh(w)"
+#	    $mmenu(group) entryconfigure $mmenu(group-undel) -state normal \
+#		-command "SetFlag $handler deleted 0 0 \
+#                \[\$${handler}(folder_handler) flagged flagged\]; focus $wh(w)"
 	    $mmenu(group) entryconfigure $mmenu(group-print) -state normal \
 		-command "Print $handler group; focus $wh(w)"
+	    $mmenu(group) entryconfigure $mmenu(group-moveto) -state normal
 	    $mmenu(group-move) configure -postcommand \
 		"PostMove $handler group $mmenu(group-move); focus $wh(w)"
 
@@ -750,7 +778,9 @@ proc ConfigMainMenu {handler} {
 		$mmenu(comp-draft) entryconfigure $mmenu(comp-draft-save) \
 		    -state disabled
 		$mmenu(comp-draft) entryconfigure $mmenu(comp-draft-restore) \
-		    -state normal -command "ComposeHeld $handler"
+		    -state normal -command "ComposeHeld"
+		$mmenu(comp) entryconfigure $mmenu(comp-send) -state disabled
+		$mmenu(comp) entryconfigure $mmenu(comp-sendsave) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-file) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-wrap) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-indent) -state disabled
@@ -798,7 +828,12 @@ proc ConfigMainMenu {handler} {
 	    $mmenu(comp-draft) entryconfigure $mmenu(comp-draft-save) \
 		-state normal -command "ComposeHold $wh(toplevel) $handler"
 	    $mmenu(comp-draft) entryconfigure $mmenu(comp-draft-restore) \
-		-state normal -command "ComposeHeld dummy"
+		-state normal -command "ComposeHeld"
+	    $mmenu(comp) entryconfigure $mmenu(comp-send) \
+		-state normal -command "DoCompose2 $wh(toplevel) $handler send"
+	    $mmenu(comp) entryconfigure $mmenu(comp-sendsave) -state normal
+	    $mmenu(comp-send_save) configure \
+		-postcommand "RatSendSavePostMenu $wh(toplevel) $mmenu(comp-send_save) $handler"
 	    $mmenu(comp) entryconfigure $mmenu(comp-file) -state normal \
 		-command "ComposeInsertFile $handler"
 	    set wh(file_menu) [list $mmenu(comp) $mmenu(comp-file)]
@@ -888,9 +923,11 @@ proc ConfigMainMenu {handler} {
 
 		# Compose menu
 		$mmenu(comp-draft) entryconfigure $mmenu(comp-draft-restore) \
-		    -state normal -command "ComposeHeld dummy"
+		    -state normal -command "ComposeHeld"
 		$mmenu(comp-draft) entryconfigure $mmenu(comp-draft-save) \
 		    -state disabled
+		$mmenu(comp) entryconfigure $mmenu(comp-send) -state disabled
+		$mmenu(comp) entryconfigure $mmenu(comp-sendsave) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-file) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-wrap) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-indent) -state disabled
@@ -938,9 +975,11 @@ proc ConfigMainMenu {handler} {
 
 		# Compose menu
 		$mmenu(comp-draft) entryconfigure $mmenu(comp-draft-restore) \
-		    -state normal -command "ComposeHeld dummy"
+		    -state normal -command "ComposeHeld"
 		$mmenu(comp-draft) entryconfigure $mmenu(comp-draft-save) \
 		    -state disabled
+		$mmenu(comp) entryconfigure $mmenu(comp-send) -state disabled
+		$mmenu(comp) entryconfigure $mmenu(comp-sendsave) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-file) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-wrap) -state disabled
 		$mmenu(comp) entryconfigure $mmenu(comp-indent) -state disabled
