@@ -66,9 +66,18 @@ proc OptionsInit {} {
     # Delivery mode
     set option(delivery_mode) direct
 
+    # whether to display the button bar
+    set option(button_bar) 1
+
     # style of buttons to use (text or image)
     set option(image_buttons) 1
 
+    # whether to display the sync button
+    set option(sync_but) 0
+
+    # what the sync button should do
+    set option(sync_oper) 0
+
     # paths and files to use for images
     set option(image_path) $env(LIBDIR)/images
 
@@ -102,14 +111,28 @@ proc OptionsInit {} {
     set icons(atchbut) $option(image_path)/attach-mini.gif
     # the attach-keys image
     set icons(keybut) $option(image_path)/keys.gif
+    # the encrypt image
+    set icons(mcryptbut) $option(image_path)/pgp-mini.gif
+    # the sign image
+    set icons(msignbut) $option(image_path)/sign-mini.gif
+    # the PGP icon
+    set icons(mlockbut) $option(image_path)/keys-mini.gif
+    # the DSN icon
+    set icons(mrecpbut) $option(image_path)/recp-mini.gif
+    # the encrypt image
+    set icons(cryptbut) $option(image_path)/pgp.gif
+    # the sign image
+    set icons(signbut) $option(image_path)/sign.gif
+    # the PGP icon
+    set icons(lockbut) $option(image_path)/keys.gif
+    # the DSN icon
+    set icons(recpbut) $option(image_path)/receipt.gif
     # the detach-file image
     set icons(dtchbut) $option(image_path)/detach-mini.gif
     # the base mbox icon
     set icons(mbox_base) $option(image_path)/mailbox.gif
     # the addresses icon
     set icons(addrbut) $option(image_path)/addresses.gif
-    # the PGP icon
-    set icons(lockbut) $option(image_path)/pgp.gif
 
     # information for the mailbox widget
     # how many list boxes?
@@ -217,6 +240,9 @@ proc OptionsInit {} {
     # Which headers to compose
     set option(compose_headers) {To Subject Cc}
 
+    # Which custom headers
+    set option(custom_headers) {}
+
     # Which editor to use (%s will be expanded to a filename)
     set option(editor) "emacs %s"
 
@@ -280,6 +306,9 @@ proc OptionsInit {} {
     # Headers to print
     set option(print_header) selected
 
+    # Should we print non-text attachments
+    set option(print_non_text) 0
+
     # Directory for temporary files
     set option(tmp) /tmp
 
@@ -353,8 +382,8 @@ proc OptionsInit {} {
     set option(dsn_verbose) {{failed notify} {delayed status} {delivered status} {relayed status} {expanded none}}
 
     # Which windows to display at startup
-    set option(start_win) [list [list compose 0] [list address 0] \
-			       [list mailboxes 0] [list folder 1]]
+    set option(start_win) [list [list mailboxes 0] [list compose 0] \
+			       [list address 0] [list folder 1]]
 
     # Whether to use a single NeXT style menu (1), or per-window menus (0)
     set option(next_menu) 0
@@ -381,6 +410,7 @@ proc OptionsInit {} {
     set option(folder_key_undelete) <Key-u>
     set option(folder_key_flag) <Key-g>
     set option(folder_key_seen) <Key-s>
+    set option(folder_key_ans) <Key-a>
     set option(folder_key_next) {<Key-Right> <Shift-Key-Down> <Key-n>}
     set option(folder_key_prev) {<Key-Left> <Shift-Key-Up> <Key-p>}
     set option(folder_key_replya) <Key-R>
@@ -389,6 +419,7 @@ proc OptionsInit {} {
     set option(folder_key_replyqa) <Key-Q>
     set option(folder_key_forward_i) <Key-f>
     set option(folder_key_forward_a) <Key-F>
+    set option(folder_key_bounce) <Key-b>
     set option(folder_key_home) {<Key-0> <Key-F27>}
     set option(folder_key_bottom) {<Key-F33> <Key-End>}
     set option(folder_key_pagedown) {<Key-space> <Key-F35> <Key-z>}
@@ -635,7 +666,8 @@ proc OptionsInit {} {
 
     # Other Invocations
     set option(ispellotherCommands) " German  { ispell -a -d deutsch } \
-		French { ispell -a -d francais } English { ispell -a -d english } "
+		French { ispell -a -d francais } \
+                English { ispell -a -d english } "
 
     # Menu popup bound to:
     set option(ispellpopupBinding) "ButtonPress-3"
@@ -648,6 +680,9 @@ proc OptionsInit {} {
 
     # Style if 'other' is selected
     set option(ispellviewStyle-Other) "-underline t -foreground red"
+
+    # Automatically expunge on folder close
+    set option(expunge_on_close) 0
 }
 
 # OptionsRead --
