@@ -38,10 +38,13 @@ set lastPref General
 # Arguments:
 
 proc Preferences {} {
+    global pref_oldFocus
     if ![winfo exists .preferences] {
 	BuildPreferences
     } else {
+	set pref_oldFocus [focus]
 	wm deiconify .preferences
+	focus .preferences
     }
 }
 
@@ -53,11 +56,11 @@ proc Preferences {} {
 # Arguments:
 
 proc BuildPreferences {} {
-    global t b pref lastPref
+    global t b pref lastPref pref_oldFocus
 
     # Initialize defaults
     set pref(options) {}
-
+    set pref_oldFocus [focus]
 
     # Initialize data table
     foreach l [GetLanguages] {
@@ -87,6 +90,10 @@ proc BuildPreferences {} {
        {print_command print_command entry} \
        {print_header print_headers option \
                {{all {$t(all)}} {selected {$t(selected)}} {none {$t(none)}}}} \
+       {print_non_text print_non_text option \
+               {{1 {$t(do)}} {0 {$t(do_not)}}}} \
+       {expunge_on_close expunge_on_close option \
+	       {{1 {$t(do)}} {0 {$t(do_not)}}}} \
        {tmp tmp_dir entry} \
        {permissions file_permissions entry} \
        {userproc userproc_file entry} \
@@ -101,6 +108,8 @@ proc BuildPreferences {} {
      set pref(Appearance) "\
        {color_set color_scheme special SetupColor} \
        {paper_color paper_color color} \
+       {button_bar button_bar option \
+               {{1 {$t(show)}} {0 {$t(dont_show)}}}} \
        {image_buttons buttons option \
                {{1 {$t(icon)}} {0 {$t(text)}}}} \
        {new_msg_col new_msg_col color} \
@@ -112,7 +121,11 @@ proc BuildPreferences {} {
        {ans_msg_col ans_msg_col color} \
        {url_color url_color color} \
      "
-     set pref(Folder) "\
+     set pref(Browser) "\
+       {sync_but sync_but option \
+               {{1 {$t(show)}} {0 {$t(dont_show)}}}} \
+       {sync_oper sync_oper option \
+               {{1 {$t(sync)}} {0 {$t(update)}}}} \
        {mboxvis mboxvis option \
                {{1 {$t(show)}} {0 {$t(dont_show)}}}} \
        {message_llength messages_shown entry} \
@@ -300,7 +313,8 @@ proc BuildPreferences {} {
     wm protocol $w WM_DELETE_WINDOW \
 	"PrefCheck; RecordSize $w.f.canvas prefCanvas; \
               RecordPos $w preferences; \
-	      destroy $w; destroy ${w}_icon"
+	      focus $pref_oldFocus; \
+              destroy $w; destroy ${w}_icon"
 
     SetIcon $w prefwin
 
@@ -382,7 +396,7 @@ proc PrefDrawTabs {w} {
     set x 2
     set maxh 0
 
-    foreach name {Startup General Appearance Folder Dbase Watcher Compose Ispell Sending 
+    foreach name {Startup General Appearance Browser Dbase Watcher Compose Ispell Sending 
 	Notification PGP} {
 	set id [$w create text [expr $x+$margin+2] [expr -0.5*$margin] \
 		-anchor sw -text $t([string tolower $name]) -tags $name]
@@ -612,7 +626,7 @@ proc PrefApply {} {
 		Popup $t(warning_sendprog)
 	    }
 	}
-	Folder {
+	Browser {
 	    if [string compare $option(message_llength) \
 			       $pref(opt,message_llength)] {
 		foreach fw $folderWindowList {
@@ -653,7 +667,7 @@ proc PrefApply {} {
 
     if $hasChanged {
 	switch $lastPref {
-	Folder {
+	Browser {
 		foreach f $folderWindowList {
 		    Sync $f 0
 		}
@@ -685,9 +699,10 @@ proc PrefCheck {} {
 
     switch $lastPref {
 	Startup {
-	    set pref(opt,start_win) [list [list compose $pref(opt,compose)] \
+	    set pref(opt,start_win) [list \
+				[list mailboxes $pref(opt,mailboxes)] \
+					 [list compose $pref(opt,compose)] \
 					 [list address $pref(opt,address)] \
-					 [list mailboxes $pref(opt,mailboxes)] \
 					 [list folder $pref(opt,folder)]]
 	}
 	Watcher {
@@ -704,7 +719,7 @@ proc PrefCheck {} {
     }
     foreach opt $pref(options) {
 	if [string compare $option($opt) $pref(opt,$opt)] {
-	    set value [RatDialog $t(unapplied_changes_title) \
+            set value [RatDialog $t(unapplied_changes_title) \
 		    $t(unapplied_changes) {} 0 $t(apply) $t(discard)]
 	    if { 0 == $value } {
 		PrefApply
