@@ -27,12 +27,12 @@
 #  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 # A list of types we can show
-set GoodTypes {text/plain message/rfc822 text/html image/gif}
+# set GoodTypes {text/plain message/rfc822 text/html image/gif}
+set GoodTypes {text/plain message/rfc822 image/gif}
 
 if $imglib {
     lappend GoodTypes {image/tiff image/pixmap iamge/jpeg image/png}
 }
-# Removed pending new image lib image/pixmap image/tiff nic 21/2/98
 
 # A list of parameters to show for different types
 set showParams(text/plain) {charset}
@@ -279,7 +279,7 @@ proc ShowMessage {first handler msg} {
     if {1 == $first && 1 == $nofh} {
 	set j [expr $index + 1]
 	$fhandler(folder_handler) setFlag $index seen 1
-	$fhandler(message_list) tag remove seen $j.0 "$j.0 lineend+1c"
+	$fhandler(message_list) tag add seen $j.0 "$j.0 lineend"
         if { 0 == $seen } {
 	    FolderListRefreshEntry $fh(handler) $index
 	}
@@ -340,7 +340,6 @@ proc ShowBody {handler body msg} {
     # Switch for subroutines which does the actual drawing
     switch -glob [lindex $type 0]/[lindex $type 1] {
 	text/plain		{ ShowTextPlain $handler $body $msg}
-	text/html               { ShowTextHTML $handler $body $msg}
 	text/*			{ ShowTextOther $handler $body $msg}
 	multipart/alternative	{ ShowMultiAlt $handler $body $msg }
 	multipart/*		{ ShowMultiMixed $handler $body $msg }
@@ -357,6 +356,7 @@ proc ShowBody {handler body msg} {
 	application/pgp         { ShowTextPlain $handler $body $msg}
 	default			{ ShowDefault $handler $body }
     }
+#	text/html               { ShowTextHTML $handler $body $msg}
 }
 
 # ShowTextPlain --
@@ -443,19 +443,25 @@ proc ShowTextPlain {handler body msg} {
 # msg     -	The message name
 
 proc ShowTextHTML {handler body msg} {
-    global option defaultFont
+    global option defaultFont libtkhtml
     upvar #0 $handler fh \
     	     msgInfo_$msg msgInfo
 
 
     set tag t[incr fh(id)]
-    $handler tag bind $tag <3> "tk_popup $fh(struct_menu) %X %Y \
-			        \[lsearch \[set ${handler}(struct_list)\] \
-			        $body\]"
+#    frame $handler.html
+    html $handler.html -bg $option(paper_color) -cursor hand2 \
+	-height 1800
+#    grid $handler.html.scroll -column 0 -row 0
+#    grid $handler.html -column 0 -row 0
     set action [$body getShowCharset]
-    $handler tag configure $tag -font [GetFont [lindex $action 1] 0 {}]
-    HMinit_win $handler
-    HMparse_html [$body data false [lindex $action 1]] "HMrender $handler"
+    $handler.html parse [$body data false [lindex $action 1]]
+    update idletasks
+    $handler window create insert -window $handler.html
+#	-yscroll "$handler.html.scroll set" \
+#    scrollbar $handler.html.scroll -command "$handler.html.text yview" \
+#	-relief sunken -highlightthickness 0
+    # -hyperlinkcommand "CallURL" 
 }
 
 # ShowTextCharset --
@@ -1041,14 +1047,19 @@ proc SaveBody {body} {
 	FileSelectorDone $fh
 	if [file exists $hd(name)] {
 	    set action [RatDialog $t(file_exists) \
-				  "$hd(name) $t(already_exists)." \
-				  {} 1 $t(overwrite) $t(cancel)]
+			    "$hd(name) $t(already_exists)." \
+			    {} 2 $t(overwrite) $t(append) $t(cancel)]
 	} else {
 	    set action 0
 	}
-	if {0 == $action} {
+	if {0 == $action || 1 == $action} {
 	    set mode [GetMode $id]
-	    if { 0 == [catch [list open $hd(name) w $mode] fh]} {
+	    if {0 == $action} {
+		set write_mode w
+	    } else {
+		set write_mode a
+	    }
+	    if { 0 == [catch [list open $hd(name) $write_mode $mode] fh]} {
 		$body saveData $fh false $hd(convertNL)
 		close $fh
 		# Defeat the umask
@@ -1056,7 +1067,7 @@ proc SaveBody {body} {
 	    } else {
 		RatLog 4 "$t(save_failed): $fh"
 	    }
-	}
+	} 
     }
 
     RecordPos $w saveBody
@@ -1319,10 +1330,11 @@ proc CallURL {url} {
 	    }
 	}
 	netscape {
+            set blahh [regsub -all , $url %2c netscape_url]
 	    if [catch {eval {exec $option(netscape)} $option(netscape_args)\
-			   {-remote "openURL($url)"} >&/dev/null}] {
+			   {-remote "openURL($netscape_url)"} >&/dev/null}] {
 		if [catch {eval {exec $option(netscape)} \
-			       $option(netscape_args) {$url} &} error] {
+			   $option(netscape_args) {$netscape_url} &} error] {
 		    Popup $error
 		}
 	    }
@@ -1380,7 +1392,7 @@ proc RatScrollShow {t scrollw sfrac efrac} {
 	set e [lindex $result 1]
 	$t tag add URL $s $e
 	$t tag add $tag $s $e
-	regsub % [$t get $s $e] %% url
+	regsub -all % [$t get $s $e] %% url
 	$t tag bind $tag <ButtonRelease-1> [list RatShowURL $url %W $tag %x %y]
 	$t tag bind $tag <1> \
 		"$t tag configure $tag -underline 0; update idletasks"
