@@ -31,6 +31,7 @@ set vFolderDefIdent 0
 
 # The ident of the next defined vFolderStruct
 set vFolderStructIdent 0
+set vFolderChanged 0
 
 # VFolderRead --
 #
@@ -41,7 +42,8 @@ set vFolderStructIdent 0
 
 proc VFolderRead {} {
     global vFolderDef vFolderStruct vFolderStructIdent vFolderDefIdent \
-	   vFolderVersion option vfolder_list vFolderInbox vFolderSave env
+	vFolderVersion option vfolder_list vFolderInbox vFolderSave \
+	vFolderStartup vFolderStartmin env vFolderChanged
 
     if [file readable $option(postilion_dir)/vfolderlist] {
 	source $option(postilion_dir)/vfolderlist
@@ -52,16 +54,45 @@ proc VFolderRead {} {
 	if [info exists vfolder_list] {
 	    FixVFolderList
 	}
-	set vFolderVersion 4
+	set vFolderVersion 5
     }
+
+    # Add mailbox feature element
     if {3 == $vFolderVersion} {
 	foreach id [array names vFolderDef] {
 	    if { {} != [lindex $vFolderDef($id) 2]} {
 		set vFolderDef($id) [lreplace $vFolderDef($id) 2 0 {}]
 	    }
 	}
-	set vFolderVersion 4
+	incr vFolderChanged
+	set vFolderVersion 5
     }
+
+    if ![info exists vFolderSave] {
+	set vFolderSave {}
+    } else {
+	set option(save_to) $vFolderSave
+    }
+
+    # Optimize mailbox feature list from older versions
+    if {4 == $vFolderVersion} {
+	foreach id [array names vFolderDef] {
+	    array set feat [lindex $vFolderDef($id) 2]
+	    foreach elem [array names feat] {
+		if [string compare $feat($elem) $option($elem)] {
+		    lappend feats $elem $feat($elem)
+		}
+	    }
+            if [info exists feats] {
+	        set vFolderDef($id) [lreplace $vFolderDef($id) 2 2 $feats]
+                unset feats
+            }
+	    unset feat
+	}
+	incr vFolderChanged
+	set vFolderVersion 5
+    }
+
     if {0 == [llength [array names vFolderDef]]} {
 	set vFolderDefIdent 1
 	set vFolderDef(0) $option(default_folder)
@@ -69,12 +100,17 @@ proc VFolderRead {} {
 	set vFolderVersion 4
 	set vFolderInbox 0
 	set vFolderSave {}
+	set vFolderStartup {}
+	set vFolderStartmin {}
     }
     if ![info exists vFolderInbox] {
 	set vFolderInbox 0
     }
-    if ![info exists vFolderSave] {
-	set vFolderSave {}
+    if ![info exists vFolderStartup] {
+	set vFolderStartup {}
+    }
+    if ![info exists vFolderStartmin] {
+	set vFolderStartmin {}
     }
     if ![info exists vFolderDef($vFolderInbox)] {
 	set vFolderInbox [lindex [lsort -integer [array names vFolderDef]] 0]
@@ -100,6 +136,7 @@ proc VFolderRead {} {
 		}
 	    }
 	}
+	# Read in new system mailbox definitions
 	source $option(system_mailboxes)
     }
 }
@@ -151,8 +188,8 @@ proc SelectFileFolder {handler} {
 
     # Do open
     if { 1 == $hd(done) } {
-	if ![string compare $handler dummy] {
-	    set handler [FolderWindowInit]
+	if { 0 != [string compare $handler dummy]} {
+	    set handler [FolderWindowInit 1]
 	}
 	upvar #0 $handler mh
 	set mh(start_selection) $option(start_selection)
@@ -160,7 +197,7 @@ proc SelectFileFolder {handler} {
 	set mh(folder_sort) $option(folder_sort)
 	set mh(signature) $option(signature)
 	FileSelectorDone $fh
-	FolderRead $handler "RatOpenFolder std $hd(name)"
+	FolderRead $handler "RatOpenFolder std $hd(name) $option(folder_sort)"
 	focus $mh(w)
     }
     unset hd
@@ -268,8 +305,8 @@ proc SelectDbasefolder {handler} {
 	    set exp "$exp all [list $hd(all)]"
 	}
 	if [string compare $hd(op) $exp] {
-	    if ![string compare $handler dummy] {
-		set handler [FolderWindowInit]
+	    if { 0 != [string compare $handler dummy]} {
+		set handler [FolderWindowInit 1]
 	    }
 	    upvar #0 $handler fh
 	    set fh(start_selection) $option(start_selection)
@@ -363,7 +400,7 @@ proc VFolderOpen {handler vfolder} {
 
     # If we're passed a dummy handler, create a new folder window
     if ![string comp $handler dummy] {
-	set handler [FolderWindowInit]
+	set handler [FolderWindowInit 1]
     }
 
     upvar #0 $handler fh
@@ -387,25 +424,9 @@ proc VFolderOpen {handler vfolder} {
     }
     set fh(browse) $mode
 
-    # Initialize sort mode
-    if [info exists fh(fs_save)] {
-	set option(folder_sort) $fh(fs_save)
-    }
-    switch $option(sort_mode) {
-	normal {set mode $option(folder_sort)}
-	folder {
-	    if ![info exists features(folder_sort)] {
-		set features(folder_sort) $option(folder_sort)
-	    }
-	    set mode $features(folder_sort)
-	}
-    }
-    set fh(folder_sort) $mode
-    set fh(fs_save) $option(folder_sort)
-    set option(folder_sort) $fh(folder_sort)
-
     # Initialize other features
     foreach feature {
+	{sort_mode folder_sort}
 	{list_mode list_format}
 	{sig_mode signature}
 	{strsel_mode start_selection}
@@ -442,19 +463,20 @@ proc VFolderOpen {handler vfolder} {
 	imap {
 	    if [string compare [lindex $vfolder 4] UsEr] {
 		set folder [FolderRead $handler "RatOpenFolder std \
-		    [lindex $vfolder 3] [lindex $vfolder 4] IMAP"]
+		    [lindex $vfolder 3] $fh(folder_sort) [lindex $vfolder 4] \
+		    IMAP"]
 	    } else {
 		set folder [FolderRead $handler "RatOpenFolder std \
-		    [lindex $vfolder 3] $env(USER) IMAP"]
+		    [lindex $vfolder 3] $fh(folder_sort) $env(USER) IMAP"]
 	    }
 	}
 	pop3 {
 	    set folder [FolderRead $handler "RatOpenFolder std \
-		    [lindex $vfolder 3] [lindex $vfolder 4] POP3"]
+		[lindex $vfolder 3] $fh(folder_sort) [lindex $vfolder 4] POP3"]
 	}
 	default {
 	    set folder [FolderRead $handler "RatOpenFolder std \
-		    [lindex $vfolder 3]"]
+		    [lindex $vfolder 3] $fh(folder_sort)"]
 	}
     }
     if [string length $folder] {
