@@ -180,7 +180,7 @@ proc VFolderNew {type} {
 #
 # Arguments:
 proc VFolderCreateMenu {} {
-    global vFolderCurrent t idCnt
+    global vFolderCurrent t b idCnt
 
     # Create identifier
     set id createSubmenu[incr idCnt]
@@ -196,6 +196,7 @@ proc VFolderCreateMenu {} {
     # Folder name
     frame $w.name
     label $w.name.label -text $t(name):
+    set b($w.name) vd_menuname
     entry $w.name.entry -textvariable ${id}(name) -width 20
     pack $w.name.entry \
 	 $w.name.label -side right
@@ -209,6 +210,7 @@ proc VFolderCreateMenu {} {
     grab $w
     tkwait variable ${id}(done)
     RecordPos $w vFolderCreateMenu
+    unset b($w.name)
     destroy $w
     focus $oldFocus
 
@@ -232,7 +234,7 @@ proc VFolderCreateMenu {} {
 #
 # Arguments:
 proc EditVFolderEntry {} {
-    global t idCnt vFolderCurrent vFolderStruct vFolderChanged vFolderDef
+    global t b idCnt vFolderCurrent vFolderStruct vFolderChanged vFolderDef
 
     set sIdent [lindex $vFolderCurrent 0]
     set index [lindex $vFolderCurrent 1]
@@ -257,6 +259,7 @@ proc EditVFolderEntry {} {
 	    entry $w.name.entry -textvariable ${id}(name) -width 20
 	    pack $w.name.label $w.name.entry -side left
 	    pack $w.name -side top -expand 1 -padx 5 -pady 5
+	    set b($w.name.entry) vd_menuname
 	    OkButtons $w $t(ok) $t(cancel) "set ${id}(done)"
 	    pack $w.buttons -fill both -padx 5 -pady 5
 
@@ -280,6 +283,7 @@ proc EditVFolderEntry {} {
 	    RecordPos $w editVfolderEntry
 	    destroy $w
 	    focus $oldFocus
+	    unset b($w.name.entry)
 	    unset hd
 	}
     vfolder {
@@ -328,7 +332,7 @@ proc VFolderDelete {} {
 	    } 
 	    if {0 == $ret} {
 		catch {RatImapDeleteFolder [lindex [lindex $vd 3] 0] \
-			[lindex $vd 3]}
+			[lindex $vd 4]}
 	    }
 	}
 	unset vFolderDef([lindex $elem 1])
@@ -349,7 +353,7 @@ proc VFolderDelete {} {
 # This procedure marks the selected folder as a special mailbox.
 #
 # Arguments:
-# what - What kind of of special feature this mailbox have
+# what - What kind of of special feature this mailbox has
 proc VFolderSetToSpecial {what} {
     global t vFolderCurrent vFolderStruct vFolderChanged
     upvar #0 vFolder$what special
@@ -357,11 +361,26 @@ proc VFolderSetToSpecial {what} {
     set sIdent [lindex $vFolderCurrent 0]
     set index [lindex $vFolderCurrent 1]
     set elem [lindex $vFolderStruct($sIdent) $index]
+    set mbox [lindex $elem 1]
     if {![string compare Save $what] &&
-	    ![string compare $special [lindex $elem 1]]} {
+	    ![string compare $special $mbox]} {
 	set special {}
+    } elseif ![string compare Startup $what] {
+	if ![lsearch -exact $special $mbox] {
+	    set special [lreplace special [lsearch -exact $special $mbox] \
+			     [lsearch -exact $special $mbox]]
+	} else {
+	    lappend special $mbox
+	}
+    } elseif ![string compare Startmin $what] {
+	if ![lsearch -exact $special $mbox] {
+	    set special [lreplace $special [lsearch -exact $special $mbox] \
+			     [lsearch -exact $special $mbox]]
+	} else {
+	    lappend special $mbox
+	}
     } else {
-	set special [lindex $elem 1]
+	set special $mbox
     }
     incr vFolderChanged
     RedrawVFolderList
@@ -391,7 +410,7 @@ proc VFolderDeleteStruct {op sIdent} {
 		}
 		if {0 == $op} {
 		    catch {RatImapDeleteFolder [lindex [lindex $vd 3] 0] \
-			    [lindex $vd 3]}
+			    [lindex $vd 4]}
 		}
 	    }
 	    unset vFolderDef([lindex $elem 1])
@@ -406,7 +425,7 @@ proc VFolderDeleteStruct {op sIdent} {
 # Arguments:
 # ident -	The identity in the vFolderDef array of the vfolder
 proc EditVFolder {ident} {
-    global t idCnt vFolderChanged vFolderDef option vFolderSave env
+    global t b idCnt vFolderChanged vFolderDef option vFolderSave env
     upvar #0 vFolderDef($ident) def
 
     # Create identifier
@@ -428,6 +447,7 @@ proc EditVFolder {ident} {
     pack $w.name.label $w.name.entry -side left
     pack $w.name -side top -expand 1 -padx 5 -pady 5
     bind $w <Return> {}
+    set b($w.name.entry) vd_name
 
     # Features
     array set hd [lindex $def 2]
@@ -575,6 +595,7 @@ proc EditVFolder {ident} {
 	    pack $w.mhn.label \
 		$w.mhn.entry -side left -pady 5
 	    pack $w.mhn -side top
+	    set b($w.mhn.entry) vd_mhname
 	}
 	dbase {
 	    set hd(keywords) [lindex $def 3]
@@ -584,20 +605,25 @@ proc EditVFolder {ident} {
 	    label $w.keywords.label -text $t(keywords):
 	    entry $w.keywords.entry -textvariable ${id}(keywords) -width 20
 	    pack $w.keywords.entry \
-		$w.keywords.label -side right
+		 $w.keywords.label -side right
+	    set b($w.keywords.entry) keywords
 	    frame $w.extype
 	    label $w.extype.label -text $t(extype):
 	    frame $w.extype.b
 	    radiobutton $w.extype.b.none -text $t(none) \
-		-variable ${id}(extype) -value none
+		    -variable ${id}(extype) -value none
+	    set b($w.extype.b.none) exp_none
 	    radiobutton $w.extype.b.remove -text $t(remove) \
-		-variable ${id}(extype) -value remove
+		    -variable ${id}(extype) -value remove
+	    set b($w.extype.b.none) exp_remove
 	    radiobutton $w.extype.b.incoming -text $t(add_incoming) \
-		-variable ${id}(extype) -value incoming
+		    -variable ${id}(extype) -value incoming
+	    set b($w.extype.b.none) exp_incoming
 	    radiobutton $w.extype.b.backup -text $t(backup) \
 		-variable ${id}(extype) -value backup
 	    radiobutton $w.extype.b.custom -variable ${id}(extype) \
 		-value custom -state disabled
+	    set b($w.extype.b.none) exp_backup
 	    pack $w.extype.b.none \
 		$w.extype.b.remove \
 		$w.extype.b.incoming \
@@ -608,6 +634,7 @@ proc EditVFolder {ident} {
 	    frame $w.exdate
 	    label $w.exdate.label -text $t(exdate):
 	    entry $w.exdate.entry -textvariable ${id}(exdate) -width 20
+	    set b($w.exdate.entry) exp_date
 	    pack $w.exdate.entry \
 		$w.exdate.label -side right
 	    pack $w.keywords \
@@ -629,26 +656,14 @@ proc EditVFolder {ident} {
 	    regsub {.+\}} $h {} hd(mbox)
 	    set oldHost $hd(host)
 	    set oldMbox $hd(mbox)
-	    frame $w.host
-	    label $w.host.label -text $t(host): -width 17 -anchor e
-	    entry $w.host.entry -textvariable ${id}(host) -width 30
-	    pack $w.host.label $w.host.entry -side left
-	    frame $w.user
-	    label $w.user.label -text $t(user): -width 17 -anchor e
-	    entry $w.user.entry -textvariable ${id}(user) -width 30
-	    pack $w.user.label $w.user.entry -side left
-	    frame $w.mbox
-	    label $w.mbox.label -text $t(mbox): -width 17 -anchor e
-	    entry $w.mbox.entry -textvariable ${id}(mbox) -width 30
-	    pack $w.mbox.label $w.mbox.entry -side left
-	    frame $w.port
-	    label $w.port.label -text $t(port): -width 17 -anchor e
-	    entry $w.port.entry -textvariable ${id}(port) -width 30
-	    pack $w.port.label $w.port.entry -side left
-	    pack $w.host \
-		$w.user \
-		$w.mbox \
-		$w.port -side top -fill both
+	    foreach e {host user mbox port} {
+		frame $w.$e
+		label $w.$e.label -text $t($e): -width 17 -anchor e
+		entry $w.$e.entry -textvariable ${id}($e) -width 30
+		pack $w.$e.label $w.$e.entry -side left
+		pack $w.$e -side top -fill both
+		set b($w.$e.entry) vd_$e
+	    }
 	}
 	pop3 {
 	    set hd(user) [lindex $def 4]
@@ -659,21 +674,14 @@ proc EditVFolder {ident} {
 	    if {2 == [llength $hlist]} {
 		set hd(port) [lindex $hlist 1]
 	    }
-	    frame $w.host
-	    label $w.host.label -text $t(host): -width 17 -anchor e
-	    entry $w.host.entry -textvariable ${id}(host) -width 30
-	    pack $w.host.label $w.host.entry -side left
-	    frame $w.user
-	    label $w.user.label -text $t(user): -width 17 -anchor e
-	    entry $w.user.entry -textvariable ${id}(user) -width 30
-	    pack $w.user.label $w.user.entry -side left
-	    frame $w.port
-	    label $w.port.label -text $t(port): -width 17 -anchor e
-	    entry $w.port.entry -textvariable ${id}(port) -width 30
-	    pack $w.port.label $w.port.entry -side left
-	    pack $w.host \
-		$w.user \
-		$w.port -side top -fill both
+	    foreach e {host user port} {
+		frame $w.$e
+		label $w.$e.label -text $t($e): -width 17 -anchor e
+		entry $w.$e.entry -textvariable ${id}($e) -width 30
+		pack $w.$e.label $w.$e.entry -side left
+		pack $w.$e -side top -fill both
+		set b($w.$e.entry) vd_$e
+	    }
 	}
 	dynamic {
 	    set hd(fname) [lindex $def 3]
@@ -709,13 +717,16 @@ proc EditVFolder {ident} {
 	tkwait variable ${id}(done)
 
 	if { 1 == $hd(done) } {
+	    set hd(name) [string trim $hd(name)]
 	    if ![string length $hd(name)] {
 		Popup $t(need_name)
 		continue
 	    }
 	    set features {}
 	    foreach elem $feats {
-		lappend features $elem $hd($elem)
+		if [string compare $hd($elem) $option($elem)] {
+		    lappend features $elem $hd($elem)
+		}
 	    }
 	    switch [lindex $def 1] {
 	    file {
@@ -794,12 +805,14 @@ proc EditVFolder {ident} {
 	    focus $oldFocus
 	    set name $hd(name)
 	    unset hd
+	    foreach bn [array names b $w.*] {unset b($bn)}
 	    return $name
 	} else {
 	    RecordPos $w editVfolder
 	    destroy $w
 	    focus $oldFocus
 	    unset hd
+	    foreach bn [array names b $w.*] {unset b($bn)}
 	    return ""
 	}
     }
@@ -853,7 +866,8 @@ proc PostSaveTo {hd m id} {
 # Arguments:
 proc VFolderWrite {} {
     global option vFolderDef vFolderStruct vFolderDefIdent vFolderStructIdent \
-	   vFolderVersion vFolderInbox vFolderSave
+	vFolderVersion vFolderInbox vFolderSave vFolderStartup \
+	vFolderStartmin
 
     set fh [open $option(postilion_dir)/vfolderlist w]
     puts $fh "set vFolderVersion $vFolderVersion"
@@ -861,6 +875,33 @@ proc VFolderWrite {} {
     puts $fh "set vFolderDefIdent $vFolderDefIdent"
     puts $fh "set vFolderInbox $vFolderInbox"
     puts $fh "set vFolderSave [list $vFolderSave]"
+    puts $fh "set vFolderStartup [list $vFolderStartup]"
+    puts $fh "set vFolderStartmin [list $vFolderStartmin]"
+
+    # First, get rid of System definitions, no point in saving those
+    if {[file readable $option(system_mailboxes)] \
+	    && $option(use_system_mboxes)} {
+	# Throw away any existing vfolderdefs which are really system
+	# defs, these may be left over from a save
+	foreach vfd [array names vFolderDef "S*"] {
+	    unset vFolderDef($vfd)
+	}
+	# Do the same for vfolderstructs
+	foreach vfs [array names vFolderStruct "S*"] {
+	    unset vFolderStruct($vfs)
+	}
+	# Get rid of lingering references within other structdefs
+	foreach str [array names vFolderStruct] {
+	    set i 0
+	    foreach elem $vFolderStruct($str) {
+		if [string match S* [lindex $elem 1]] {
+		    set vFolderStruct($str) [lreplace $vFolderStruct($str) $i $i]
+		} else {
+		    incr i
+		}
+	    }
+	}
+    }
 
     foreach str [array names vFolderStruct] {
 	set vs {}
@@ -873,6 +914,7 @@ proc VFolderWrite {} {
 		    set keep [info exists vFolderDef([lindex $e 1])]
 		}
 	    }
+	    
 	    if $keep {
 		lappend vs $e
 	    } else {
@@ -884,6 +926,13 @@ proc VFolderWrite {} {
     foreach elem [array names vFolderDef] {
 	puts $fh "set vFolderDef($elem) [list $vFolderDef($elem)]"
     }
+
+    # Restore System definitions
+    if {[file readable $option(system_mailboxes)] \
+	    && $option(use_system_mboxes)} {
+	source $option(system_mailboxes)
+    }
+
     close $fh
 }
 
@@ -895,7 +944,9 @@ proc VFolderWrite {} {
 # Arguments:
 proc VFolderWindowDestroy {} {
     global vFolderChanged
-    if $vFolderChanged {VFolderWrite}
+    if $vFolderChanged {
+	VFolderWrite
+    }
 }
 
 # VFolderImportDirectory --
@@ -906,7 +957,7 @@ proc VFolderWindowDestroy {} {
 # Arguments:
 proc VFolderImportDirectory {} {
     global vFolderDefIdent vFolderStruct vFolderChanged vFolderStructIdent\
-	   vFolderDef t idCnt
+	   vFolderDef t b idCnt
 
     # Create identifier
     set id importMailDir[incr idCnt]
@@ -931,8 +982,10 @@ proc VFolderImportDirectory {} {
     label $w.pat.lab -text $t(patterns_to_use)
     label $w.pat.labf -text $t(files):
     entry $w.pat.entf -textvariable ${id}(file_pattern)
+    set b($w.pat.entf) vd_filepat
     label $w.pat.labd -text $t(directories):
     entry $w.pat.entd -textvariable ${id}(dir_pattern)
+    set b($w.pat.entd) vd_dirpat
     grid $w.pat.lab -columnspan 2
     grid $w.pat.labf -row 1 -column 0 -sticky e
     grid $w.pat.entf -row 1 -column 1 -sticky ew
@@ -948,6 +1001,8 @@ proc VFolderImportDirectory {} {
     grab $w
     tkwait variable ${id}(done)
     RecordPos $w vFolderImportDirectory
+    unset b($w.pat.entf)
+    unset b($w.pat.entd)
     destroy $w
 
     if {1 == $hd(done)} {
@@ -1040,20 +1095,18 @@ proc VFolderImportMHDirectory {} {
     # The patterns
     frame $w.pat
     label $w.pat.lab -text $t(patterns_to_use)
-    label $w.pat.labf -text $t(files):
+    label $w.pat.labf -text $t(files): -anchor e
     entry $w.pat.entf -textvariable ${id}(file_pattern)
-    label $w.pat.labd -text $t(directories):
+    label $w.pat.labd -text $t(directories): -anchor e
     entry $w.pat.entd -textvariable ${id}(dir_pattern)
     grid $w.pat.lab -columnspan 2
-    grid $w.pat.labf -row 1 -column 0 -sticky e
-    grid $w.pat.entf -row 1 -column 1 -sticky ew
-    grid $w.pat.labd -row 2 -column 0 -sticky e
-    grid $w.pat.entd -row 2 -column 1 -sticky ew
+    grid $w.pat.labf $w.pat.entf -sticky ew
+    grid $w.pat.labd $w.pat.entd -sticky ew
     pack $w.pat
 
     OkButtons $w $t(ok) $t(cancel) "set ${id}(done)"
     pack $w.buttons \
-	 $w.chooser -side bottom -fill both -padx 5 -pady 5
+    	 $w.chooser -side bottom -fill both -expand 1 -padx 5 -pady 5
 
     Place $w vFolderImportDirectory
     grab $w
@@ -1096,9 +1149,12 @@ proc VFolderMHHasSubfolders { dirName } {
 # dirName      - Name of the directory
 # file_pattern - pattern to match files against
 # dir_pattern  - pattern to match directories against
-proc VFolderMHScanDir {sid dirName file_pattern dir_pattern {folder_prefix {}}} {
+proc VFolderMHScanDir {sid dirName file_pattern dir_pattern {folder_prefix {/}}} {
     global vFolderDefIdent vFolderStruct vFolderDef vFolderStructIdent t 
-
+puts $dirName
+puts $file_pattern
+puts $dir_pattern
+puts $folder_prefix
     set vFolderStruct($sid) {}
     foreach f [lsort [glob -nocomplain $dirName/*]] {
 	set name [file tail $f]
@@ -1112,9 +1168,10 @@ proc VFolderMHScanDir {sid dirName file_pattern dir_pattern {folder_prefix {}}}
 	    }
 	    lappend vFolderStruct($sid) \
 		    [list struct [incr vFolderStructIdent] "$name/"]
-	    VFolderMHScanDir $vFolderStructIdent $f $file_pattern $dir_pattern $name/
+	    VFolderMHScanDir $vFolderStructIdent $f $file_pattern $dir_pattern $folder_prefix$name/
 	    lappend vFolderStruct($sid) [list vfolder $vFolderDefIdent $name]
 	    set vFolderDef($vFolderDefIdent) [list $name mh {} "#MH$folder_prefix$name"]
+puts $vFolderDef($vFolderDefIdent)
 	    incr vFolderDefIdent
 	} elseif [file isfile $f] {
 	    # nothing to do...
@@ -1123,7 +1180,7 @@ proc VFolderMHScanDir {sid dirName file_pattern dir_pattern {folder_prefix {}}}
 		continue
 	    }
 	    lappend vFolderStruct($sid) [list vfolder $vFolderDefIdent $name]
-	    set vFolderDef($vFolderDefIdent) [list $name mh {} "#MH/$folder_prefix/$name"]
+	    set vFolderDef($vFolderDefIdent) [list $name mh {} "#MH$folder_prefix$name"]
 	    incr vFolderDefIdent
 	}
     }
@@ -1135,7 +1192,8 @@ proc VFolderMHScanDir {sid dirName file_pattern dir_pattern {folder_prefix {}}}
 #
 # Arguments:
 proc VFolderImportIMAP {} {
-    global t env idCnt vFolderChanged option vFolderStruct vFolderStructIdent
+    global t b env idCnt vFolderChanged option \
+	   vFolderStruct vFolderStructIdent
 
     # Create identifier
     set id importIMAP[incr idCnt]
@@ -1152,30 +1210,15 @@ proc VFolderImportIMAP {} {
     set hd(port) $option(imap_port)
     set hd(user) $env(USER)
     set hd(pattern) {*}
-    set row 0
-    label $w.host_label -text $t(host):
-    entry $w.host_entry -textvariable ${id}(host) -width 32
-    grid $w.host_label -row $row -sticky e -padx 5 -pady 5
-    grid $w.host_entry -row $row -column 1 -sticky ew -padx 5
-    incr row
-    label $w.port_label -text $t(port):
-    entry $w.port_entry -textvariable ${id}(port) -width 32
-    grid $w.port_label -row $row -sticky e -padx 5 -pady 5
-    grid $w.port_entry -row $row -column 1 -sticky ew -padx 5
-    incr row
-    label $w.user_label -text $t(user):
-    entry $w.user_entry -textvariable ${id}(user) -width 32
-    grid $w.user_label -row $row -sticky e -padx 5 -pady 5
-    grid $w.user_entry -row $row -column 1 -sticky ew -padx 5
-    incr row
-    label $w.pattern_label -text $t(pattern):
-    entry $w.pattern_entry -textvariable ${id}(pattern) -width 32
-    grid $w.pattern_label -row $row -sticky e -padx 5 -pady 5
-    grid $w.pattern_entry -row $row -column 1 -sticky ew -padx 5
-    incr row
+    foreach e {host port user pattern} {
+	label $w.${e}_label -text $t($e): -anchor e
+	entry $w.${e}_entry -textvariable ${id}($e) -width 32
+	set b($w.${e}_entry) vd_$e
+	grid $w.${e}_label $w.${e}_entry -sticky ew -padx 5
+    }
 
     OkButtons $w $t(ok) $t(cancel) "set ${id}(done)"
-    grid $w.buttons -row $row -columnspan 2 -pady 10 -sticky ew
+    grid $w.buttons -columnspan 2 -pady 10 -sticky ew
 
     Place $w vFolderImportIMAP
     focus $w.host_entry
@@ -1200,11 +1243,7 @@ proc VFolderImportIMAP {} {
 	if [catch $cmd folders] {
 	    Popup "$t(import_failed): $folders"
 	} else {
-	    if [info exists vFolderChanged] {
-		incr vFolderChanged
-	    } else {
-		set vFolderChanged 1
-	    }
+	    incr vFolderChanged
 	    if [info exists vFolderStructIdent] {
 		incr vFolderStructIdent
 	    } else {
